'''
Created on 05-Sep-2019

@author: rahuljain
'''

WILLIAM_K_UL = -75
WILLIAM_K_LL = -25
fundamental_info_cols = ['EarningYield', 'FCFYield', 'ROC', 'BookToMkt', 'DivYield', 'EPS Growth Rate',
                          'EPS', 'Yahoo 1 yr target', 'Intrinsic Value']

STOCK_DETAIL_MODEL_KEY_MAP = {
  'Sector'                                          : 'sector',
  'Stock Name'                                      : 'stock',
  'Date'                                            : 'run_date',
  'Last Close'                                      : 'last_close',
  'Last COB'                                        : 'last_cob',
  'Average Volume'                                  : 'avg_volume',
  'Standard Deviation'                              : 'std_dev',
  'Annual Volatility'                               : 'annual_volatility',
  'CAGR'                                            : 'cagr',
  'Sharpe'                                          : 'sharpe',
  'Sortino'                                         : 'sortino',               
  'Return 1D'                                       : 'return_1d',
  'Return 1W'                                       : 'return_1w',
  'Return 1M'                                       : 'return_1m',
  'Return 1Y'                                       : 'return_1y',
  '52W High'                                        : 'high_52w',
  '52W Low'                                         : 'low_52w',
  'Price% 52 Week'                                  : 'price_per_52w',
  'Price per Range'                                 : 'price_range_52w',
  'Smoothing Period'                                : 'william_smoothing_period',
  'Lookback Period'                                 : 'william_lookback_period',
  '%R'                                              : 'william_r_perc',
  '%D'                                              : 'william_d_perc',
  'WilliamR Signal'                                 : 'william_signal',
  '30D Moving Average'                              : 'ma_30day',
  '60D Moving Average'                              : 'ma_60day',
  '200D Moving Average'                             : 'ma_200day',
  '12D Exponential Moving Average'                  : 'ema_12day',
  '26D Exponential Moving Average'                  : 'ema_26day',
  'MACD Line'                                       : 'macd_line',
  'MACD Indicator'                                  : 'macd_ind',
  'MACD Line to Indicator Diff (Value)'             : 'macd_line_ind_diff_val',
  'MACD Line to Indicator Diff (Days)'              : 'macd_line_ind_diff_day',
  'MACD Line to Indicator Diff Rolling Peak'        : 'macd_line_ind_diff_roll_peak_val',
  'MACD Line to Indicator Diff Rolling Peak per'    : 'macd_line_ind_diff_roll_peak_perc',
  'MACD Signal'                                     : 'macd_signal',
  'Bollinger Band Upper'                            : 'bollinger_band_upper',
  'Bollinger Band Middle'                           : 'bollinger_band_middle',
  'Bollinger Band Lower'                            : 'bollinger_band_lower',
  'RSI Value'                                       : 'rsi_value',
  'RSI Signal'                                      : 'rsi_signal',
  'ATR Value'                                       : 'atr_value',
  'ADX Value'                                       : 'adx_value',
  'OBV Value'                                       : 'obv_value',
  'OBV Index'                                       : 'obv_index',
  'OBV Slope'                                       : 'obv_slope',
  'OBV Signal'                                      : 'obv_signal',
  'Slope Value'                                     : 'slope_value',
  'Renko Trend'                                     : 'renko_trend',
  'Renko Strength'                                  : 'renko_strength',
  'Renko Signal'                                    : 'renko_signal',
  'Renko Date'                                      : 'renko_date',
  'BookToMkt'                                       : 'book_to_market',
  'ROC'                                             : 'roc',
  'EarningYield'                                    : 'earning_yield',
  'FCFYield'                                        : 'fcf_yield',
  'DivYield'                                        : 'div_yield',
  'Yahoo 1 yr target'                               : 'yahoo_target_price',
  'Intrinsic Value'                                 : 'intrinsic_value',}

STOCK_LIST = [
{'sector' : 'Mining', 'stock' : '20MICRONS'},
{'sector' : 'Computers', 'stock' : '3IINFOTECH'},
{'sector' : 'Diversified', 'stock' : '3MINDIA'},
{'sector' : 'NA', 'stock' : '63MOONS'},
{'sector' : 'Computers', 'stock' : '8KMILES'},
{'sector' : 'Engineering', 'stock' : 'A2ZINFRA'},
{'sector' : 'Pharmaceuticals', 'stock' : 'AARTIDRUGS'},
{'sector' : 'Chemicals', 'stock' : 'AARTIIND'},
{'sector' : 'Textiles', 'stock' : 'AARVEEDEN'},
{'sector' : 'Oil Drilling', 'stock' : 'ABAN'},
{'sector' : 'Electric', 'stock' : 'ABB'},
{'sector' : 'Pharmaceuticals', 'stock' : 'ABBOTINDIA'},
{'sector' : 'Textiles', 'stock' : 'ABFRL'},
{'sector' : 'Textiles', 'stock' : 'ABIRLANUVO'},
{'sector' : 'Cement', 'stock' : 'ACC'},
{'sector' : 'Computers', 'stock' : 'ACCELYA'},
{'sector' : 'Engineering', 'stock' : 'ACE'},
{'sector' : 'Trading', 'stock' : 'ADANIENT'},
{'sector' : 'Misc', 'stock' : 'ADANIPORTS'},
{'sector' : 'Power', 'stock' : 'ADANIPOWER'},
{'sector' : 'Power', 'stock' : 'ADANITRANS'},
{'sector' : 'Food Processing', 'stock' : 'ADFFOODS'},
{'sector' : 'Steel', 'stock' : 'ADHUNIK'},
{'sector' : 'NA', 'stock' : 'ADHUNIKIND'},
{'sector' : 'Recreation / Amusement Parks', 'stock' : 'ADLABS'},
{'sector' : 'Misc', 'stock' : 'ADORWELD'},
{'sector' : 'Hotels', 'stock' : 'ADVANIHOTR'},
{'sector' : 'NA', 'stock' : 'ADVENZYMES'},
{'sector' : 'Misc', 'stock' : 'AEGISCHEM'},
{'sector' : 'Telecom', 'stock' : 'AGCNET'},
{'sector' : 'Misc', 'stock' : 'AGRITECH'},
{'sector' : 'Hotels', 'stock' : 'AHLEAST'},
{'sector' : 'Construction', 'stock' : 'AHLUCONT'},
{'sector' : 'Hotels', 'stock' : 'AHLWEST'},
{'sector' : 'Engineering', 'stock' : 'AIAENG'},
{'sector' : 'Textiles', 'stock' : 'AIFL'},
{'sector' : 'Pharmaceuticals', 'stock' : 'AJANTPHARM'},
{'sector' : 'Construction', 'stock' : 'AJMERA'},
{'sector' : 'NA', 'stock' : 'AKSHARCHEM'},
{'sector' : 'Cables', 'stock' : 'AKSHOPTFBR'},
{'sector' : 'Paints', 'stock' : 'AKZOINDIA'},
{'sector' : 'Finance', 'stock' : 'ALANKIT'},
{'sector' : 'NA', 'stock' : 'ALBERTDAVD'},
{'sector' : 'Banks - PSU', 'stock' : 'ALBK'},
{'sector' : 'Diversified', 'stock' : 'ALCHEM'},
{'sector' : 'Pharmaceuticals', 'stock' : 'ALEMBICLTD'},
{'sector' : 'Auto Ancl', 'stock' : 'ALICON'},
{'sector' : 'Metals', 'stock' : 'ALKALI'},
{'sector' : 'Pharmaceuticals', 'stock' : 'ALKEM'},
{'sector' : 'Chemicals', 'stock' : 'ALKYLAMINE'},
{'sector' : 'Transport', 'stock' : 'ALLCARGO'},
{'sector' : 'Computers', 'stock' : 'ALLSEC'},
{'sector' : 'Finance', 'stock' : 'ALMONDZ'},
{'sector' : 'Textiles', 'stock' : 'ALOKTEXT'},
{'sector' : 'Oil Drilling', 'stock' : 'ALPHAGEO'},
{'sector' : 'Textiles', 'stock' : 'ALPSINDUS'},
{'sector' : 'Auto Ancl', 'stock' : 'AMARAJABAT'},
{'sector' : 'Textiles', 'stock' : 'AMBIKCO'},
{'sector' : 'Cement', 'stock' : 'AMBUJACEM'},
{'sector' : 'Packaging', 'stock' : 'AMDIND'},
{'sector' : 'Pharmaceuticals', 'stock' : 'AMRUTANJAN'},
{'sector' : 'Auto Ancl', 'stock' : 'AMTEKAUTO'},
{'sector' : 'Construction', 'stock' : 'ANANTRAJ'},
{'sector' : 'Banks - PSU', 'stock' : 'ANDHRABANK'},
{'sector' : 'Sugar', 'stock' : 'ANDHRSUGAR'},
{'sector' : 'Diversified', 'stock' : 'ANGIND'},
{'sector' : 'Steel', 'stock' : 'ANKITMETAL'},
{'sector' : 'Construction', 'stock' : 'ANSALAPI'},
{'sector' : 'Construction', 'stock' : 'ANSALHSG'},
{'sector' : 'Electric', 'stock' : 'APARINDS'},
{'sector' : 'NA', 'stock' : 'APCL'},
{'sector' : 'Misc', 'stock' : 'APCOTEXIND'},
{'sector' : 'Steel', 'stock' : 'APLAPOLLO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'APLLTD'},
{'sector' : 'Medical', 'stock' : 'APOLLOHOSP'},
{'sector' : 'Auto Ancl', 'stock' : 'APOLLOTYRE'},
{'sector' : 'Computers', 'stock' : 'APTECHT'},
{'sector' : 'Consumer Goods', 'stock' : 'ARCHIDPLY'},
{'sector' : 'Printing', 'stock' : 'ARCHIES'},
{'sector' : 'Mining', 'stock' : 'ARCOTECH'},
{'sector' : 'Fertilisers', 'stock' : 'ARIES'},
{'sector' : 'NA', 'stock' : 'ARIHANTSUP'},
{'sector' : 'NA', 'stock' : 'ARMANFIN'},
{'sector' : 'Misc', 'stock' : 'AROGRANITE'},
{'sector' : 'NA', 'stock' : 'ARROWGREEN'},
{'sector' : 'Textiles', 'stock' : 'ARROWTEX'},
{'sector' : 'Construction', 'stock' : 'ARSSINFRA'},
{'sector' : 'Textiles', 'stock' : 'ARVIND'},
{'sector' : 'NA', 'stock' : 'ARVSMART'},
{'sector' : 'Glass', 'stock' : 'ASAHIINDIA'},
{'sector' : 'Dyes', 'stock' : 'ASAHISONG'},
{'sector' : 'Auto Ancl', 'stock' : 'ASAL'},
{'sector' : 'Mining', 'stock' : 'ASHAPURMIN'},
{'sector' : 'Construction', 'stock' : 'ASHIANA'},
{'sector' : 'Textiles', 'stock' : 'ASHIMASYN'},
{'sector' : 'Construction', 'stock' : 'ASHOKA'},
{'sector' : 'Auto', 'stock' : 'ASHOKLEY'},
{'sector' : 'Hotels', 'stock' : 'ASIANHOTNR'},
{'sector' : 'Paints', 'stock' : 'ASIANPAINT'},
{'sector' : 'Ceramics', 'stock' : 'ASIANTILES'},
{'sector' : 'Tea-Coffee', 'stock' : 'ASSAMCO'},
{'sector' : 'Agro', 'stock' : 'ASTEC'},
{'sector' : 'Plastics', 'stock' : 'ASTRAL'},
{'sector' : 'Telecom', 'stock' : 'ASTRAMICRO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'ASTRAZEN'},
{'sector' : 'Edible Oils', 'stock' : 'ATFL'},
{'sector' : 'Infrastructure', 'stock' : 'ATLANTA'},
{'sector' : 'Dyes', 'stock' : 'ATUL'},
{'sector' : 'Auto', 'stock' : 'ATULAUTO'},
{'sector' : 'Computers', 'stock' : 'AURIONPRO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'AUROPHARMA'},
{'sector' : 'Trading', 'stock' : 'AUSOMENT'},
{'sector' : 'Auto Ancl', 'stock' : 'AUTOAXLES'},
{'sector' : 'Auto Ancl', 'stock' : 'AUTOIND'},
{'sector' : 'Auto Ancl', 'stock' : 'AUTOLITIND'},
{'sector' : 'Food Processing', 'stock' : 'AVANTIFEED'},
{'sector' : 'Edible Oils', 'stock' : 'AVTNPL'},
{'sector' : 'Banks - Private', 'stock' : 'AXISBANK'},
{'sector' : 'Computers', 'stock' : 'AXISCADES'},
{'sector' : 'ETF', 'stock' : 'AXISGOLD'},
{'sector' : 'Textiles', 'stock' : 'AYMSYNTEX'},
{'sector' : 'Pharmaceuticals', 'stock' : 'BAFNAPHARM'},
{'sector' : 'Entertainment', 'stock' : 'BAGFILMS'},
{'sector' : 'Auto', 'stock' : 'BAJAJ-AUTO'},
{'sector' : 'Diversified', 'stock' : 'BAJAJCORP'},
{'sector' : 'Appliances', 'stock' : 'BAJAJELEC'},
{'sector' : 'Finance', 'stock' : 'BAJAJFINSV'},
{'sector' : 'Sugar', 'stock' : 'BAJAJHIND'},
{'sector' : 'Finance', 'stock' : 'BAJAJHLDNG'},
{'sector' : 'Finance', 'stock' : 'BAJFINANCE'},
{'sector' : 'Entertainment', 'stock' : 'BALAJITELE'},
{'sector' : 'Chemicals', 'stock' : 'BALAMINES'},
{'sector' : 'NA', 'stock' : 'BALKRISHNA'},
{'sector' : 'Auto Ancl', 'stock' : 'BALKRISIND'},
{'sector' : 'Paper', 'stock' : 'BALLARPUR'},
{'sector' : 'Diversified', 'stock' : 'BALMLAWRIE'},
{'sector' : 'Pharmaceuticals', 'stock' : 'BALPHARMA'},
{'sector' : 'Sugar', 'stock' : 'BALRAMCHIN'},
{'sector' : 'Sugar', 'stock' : 'BANARISUG'},
{'sector' : 'Auto Ancl', 'stock' : 'BANCOINDIA'},
{'sector' : 'Banks - PSU', 'stock' : 'BANKBARODA'},
{'sector' : 'ETF', 'stock' : 'BANKBEES'},
{'sector' : 'Banks - PSU', 'stock' : 'BANKINDIA'},
{'sector' : 'Index', 'stock' : 'BANKNIFTY'},
{'sector' : 'Textiles', 'stock' : 'BANSWRAS'},
{'sector' : 'Computers', 'stock' : 'BARTRONICS'},
{'sector' : 'Chemicals', 'stock' : 'BASF'},
{'sector' : 'Textiles', 'stock' : 'BASML'},
{'sector' : 'Leather', 'stock' : 'BATAINDIA'},
{'sector' : 'Agro', 'stock' : 'BAYERCROP'},
{'sector' : 'Electric', 'stock' : 'BBL'},
{'sector' : 'Tea-Coffee', 'stock' : 'BBTC'},
{'sector' : 'Electronics', 'stock' : 'BEDMUTHA'},
{'sector' : 'Electronics', 'stock' : 'BEL'},
{'sector' : 'Engineering', 'stock' : 'BEML'},
{'sector' : 'Petrochem', 'stock' : 'BEPL'},
{'sector' : 'Paints', 'stock' : 'BERGEPAINT'},
{'sector' : 'Finance', 'stock' : 'BFINVEST'},
{'sector' : 'Power', 'stock' : 'BFUTILITIE'},
{'sector' : 'Engineering', 'stock' : 'BGRENERGY'},
{'sector' : 'Dyes', 'stock' : 'BHAGERIA'},
{'sector' : 'NA', 'stock' : 'BHANDARI'},
{'sector' : 'NA', 'stock' : 'BHARATFIN'},
{'sector' : 'Auto Ancl', 'stock' : 'BHARATFORG'},
{'sector' : 'Auto Ancl', 'stock' : 'BHARATGEAR'},
{'sector' : 'NA', 'stock' : 'BHARATIDIL'},
{'sector' : 'Agro', 'stock' : 'BHARATRAS'},
{'sector' : 'NA', 'stock' : 'BHARATWIRE'},
{'sector' : 'Telecom', 'stock' : 'BHARTIARTL'},
{'sector' : 'Engineering', 'stock' : 'BHEL'},
{'sector' : 'Steel', 'stock' : 'BHUSANSTL'},
{'sector' : 'NA', 'stock' : 'BIGBLOC'},
{'sector' : 'Leather', 'stock' : 'BIL'},
{'sector' : 'Misc', 'stock' : 'BINANIIND'},
{'sector' : 'Fertilisers', 'stock' : 'BINDALAGRO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'BIOCON'},
{'sector' : 'NA', 'stock' : 'BIRLACABLE'},
{'sector' : 'Cement', 'stock' : 'BIRLACORPN'},
{'sector' : 'Pharmaceuticals', 'stock' : 'BLISSGVS'},
{'sector' : 'Construction', 'stock' : 'BLKASHYAP'},
{'sector' : 'NA', 'stock' : 'BLS'},
{'sector' : 'Textiles', 'stock' : 'BLUEBLENDS'},
{'sector' : 'Pharmaceuticals', 'stock' : 'BLUECOAST'},
{'sector' : 'Couriers', 'stock' : 'BLUEDART'},
{'sector' : 'Air Conditioners', 'stock' : 'BLUESTARCO'},
{'sector' : 'Dyes', 'stock' : 'BODALCHEM'},
{'sector' : 'Petrochem', 'stock' : 'BOMDYEING'},
{'sector' : 'Auto Ancl', 'stock' : 'BOSCHLTD'},
{'sector' : 'Refineries', 'stock' : 'BPCL'},
{'sector' : 'Consumer Goods', 'stock' : 'BPL'},
{'sector' : 'Textiles', 'stock' : 'BRFL'},
{'sector' : 'Construction', 'stock' : 'BRIGADE'},
{'sector' : 'Food Processing', 'stock' : 'BRITANNIA'},
{'sector' : 'Pharmaceuticals', 'stock' : 'BROOKS'},
{'sector' : 'NA', 'stock' : 'BSE'},
{'sector' : 'Textiles', 'stock' : 'BSL'},
{'sector' : 'Transmisson Line Towers / Equipment', 'stock' : 'BSLIMITED'},
{'sector' : 'Cement', 'stock' : 'BURNPUR'},
{'sector' : 'Appliances', 'stock' : 'BUTTERFLY'},
{'sector' : 'Hotels', 'stock' : 'BYKE'},
{'sector' : 'Pharmaceuticals', 'stock' : 'CADILAHC'},
{'sector' : 'Chemicals', 'stock' : 'CAMLINFINE'},
{'sector' : 'Banks - PSU', 'stock' : 'CANBK'},
{'sector' : 'Finance', 'stock' : 'CANFINHOME'},
{'sector' : 'Textiles', 'stock' : 'CANTABIL'},
{'sector' : 'Finance', 'stock' : 'CAPF'},
{'sector' : 'Pharmaceuticals', 'stock' : 'CAPLIPOINT'},
{'sector' : 'NA', 'stock' : 'CAPTRUST'},
{'sector' : 'Grinding Wheels', 'stock' : 'CARBORUNIV'},
{'sector' : 'Misc', 'stock' : 'CAREERP'},
{'sector' : 'Misc', 'stock' : 'CARERATING'},
{'sector' : 'Auto Ancl', 'stock' : 'CASTEXTECH'},
{'sector' : 'Chemicals', 'stock' : 'CASTROLIND'},
{'sector' : 'Hotels', 'stock' : 'CCHHL'},
{'sector' : 'Tea-Coffee', 'stock' : 'CCL'},
{'sector' : 'Auto Ancl', 'stock' : 'CEATLTD'},
{'sector' : 'Engineering', 'stock' : 'CEBBCO'},
{'sector' : 'Textiles', 'stock' : 'CELEBRITY'},
{'sector' : 'Pharmaceuticals', 'stock' : 'CELESTIAL'},
{'sector' : 'Textiles', 'stock' : 'CENTENKA'},
{'sector' : 'Banks - PSU', 'stock' : 'CENTRALBK'},
{'sector' : 'Electronics', 'stock' : 'CENTUM'},
{'sector' : 'Consumer Goods', 'stock' : 'CENTURYPLY'},
{'sector' : 'Diversified', 'stock' : 'CENTURYTEX'},
{'sector' : 'Ceramics', 'stock' : 'CERA'},
{'sector' : 'Computers', 'stock' : 'CEREBRAINT'},
{'sector' : 'Power', 'stock' : 'CESC'},
{'sector' : 'Finance', 'stock' : 'CGCL'},
{'sector' : 'NA', 'stock' : 'CGPOWER'},
{'sector' : 'Fertilisers', 'stock' : 'CHAMBLFERT'},
{'sector' : 'Chemicals', 'stock' : 'CHEMFALKAL'},
{'sector' : 'Refineries', 'stock' : 'CHENNPETRO'},
{'sector' : 'Finance', 'stock' : 'CHOLAFIN'},
{'sector' : 'Dyes', 'stock' : 'CHROMATIC'},
{'sector' : 'Computers', 'stock' : 'CIGNITITEC'},
{'sector' : 'Entertainment', 'stock' : 'CINELINE'},
{'sector' : 'Pharmaceuticals', 'stock' : 'CIPLA'},
{'sector' : 'NA', 'stock' : 'CLEDUCATE'},
{'sector' : 'Dyes', 'stock' : 'CLNINDIA'},
{'sector' : 'NA', 'stock' : 'CMICABLES'},
{'sector' : 'Textiles', 'stock' : 'CNOVAPETRO'},
{'sector' : 'Mining', 'stock' : 'COALINDIA'},
{'sector' : 'Hotels', 'stock' : 'COFFEEDAY'},
{'sector' : 'FMCG', 'stock' : 'COLPAL'},
{'sector' : 'NA', 'stock' : 'COMPINFO'},
{'sector' : 'Computers', 'stock' : 'COMPUSOFT'},
{'sector' : 'Transport', 'stock' : 'CONCOR'},
{'sector' : 'Finance', 'stock' : 'CONSOFINVT'},
{'sector' : 'NA', 'stock' : 'CONTROLPR'},
{'sector' : 'Cables', 'stock' : 'CORDSCABLE'},
{'sector' : 'Fertilisers', 'stock' : 'COROMANDEL'},
{'sector' : 'Banks - PSU', 'stock' : 'CORPBANK'},
{'sector' : 'Plastics', 'stock' : 'COSMOFILMS'},
{'sector' : 'Construction', 'stock' : 'COUNCODOS'},
{'sector' : 'Travel', 'stock' : 'COX&KINGS'},
{'sector' : 'Misc', 'stock' : 'CRISIL'},
{'sector' : 'NA', 'stock' : 'CROMPTON'},
{'sector' : 'Computers', 'stock' : 'CTE'},
{'sector' : 'Banks - Private', 'stock' : 'CUB'},
{'sector' : 'Engines', 'stock' : 'CUMMINSIND'},
{'sector' : 'NA', 'stock' : 'CUPID'},
{'sector' : 'Computers', 'stock' : 'CYBERTECH'},
{'sector' : 'Computers', 'stock' : 'CYIENT'},
{'sector' : 'Misc', 'stock' : 'DAAWAT'},
{'sector' : 'FMCG', 'stock' : 'DABUR'},
{'sector' : 'Refractories / Intermediates', 'stock' : 'DALMIABHA'},
{'sector' : 'Sugar', 'stock' : 'DALMIASUG'},
{'sector' : 'NA', 'stock' : 'DAMODARIND'},
{'sector' : 'Computers', 'stock' : 'DATAMATICS'},
{'sector' : 'Printing', 'stock' : 'DBCORP'},
{'sector' : 'NA', 'stock' : 'DBL'},
{'sector' : 'Construction', 'stock' : 'DBREALTY'},
{'sector' : 'Finance', 'stock' : 'DBSTOCKBRO'},
{'sector' : 'Banks - Private', 'stock' : 'DCBBANK'},
{'sector' : 'Textiles', 'stock' : 'DCM'},
{'sector' : 'Diversified', 'stock' : 'DCMSHRIRAM'},
{'sector' : 'Petrochem', 'stock' : 'DCW'},
{'sector' : 'Cement', 'stock' : 'DECCANCE'},
{'sector' : 'Fertilisers', 'stock' : 'DEEPAKFERT'},
{'sector' : 'Chemicals', 'stock' : 'DEEPAKNTR'},
{'sector' : 'Misc', 'stock' : 'DEEPIND'},
{'sector' : 'Diversified', 'stock' : 'DELTACORP'},
{'sector' : 'Electronics', 'stock' : 'DELTAMAGNT'},
{'sector' : 'Entertainment', 'stock' : 'DEN'},
{'sector' : 'Banks - PSU', 'stock' : 'DENABANK'},
{'sector' : 'Misc', 'stock' : 'DENORA'},
{'sector' : 'NA', 'stock' : 'DFMFOODS'},
{'sector' : 'Sugar', 'stock' : 'DHAMPURSUG'},
{'sector' : 'Banks - Private', 'stock' : 'DHANBANK'},
{'sector' : 'Agro', 'stock' : 'DHANUKA'},
{'sector' : 'Sugar', 'stock' : 'DHARSUGAR'},
{'sector' : 'Finance', 'stock' : 'DHFL'},
{'sector' : 'Finance', 'stock' : 'DHUNINV'},
{'sector' : 'Cables', 'stock' : 'DIAPOWER'},
{'sector' : 'Printing', 'stock' : 'DICIND'},
{'sector' : 'NA', 'stock' : 'DIGJAMLTD'},
{'sector' : 'Pharmaceuticals', 'stock' : 'DISHMAN'},
{'sector' : 'Entertainment', 'stock' : 'DISHTV'},
{'sector' : 'Pharmaceuticals', 'stock' : 'DIVISLAB'},
{'sector' : 'Construction', 'stock' : 'DLF'},
{'sector' : 'Misc', 'stock' : 'DLINKINDIA'},
{'sector' : 'NA', 'stock' : 'DMART'},
{'sector' : 'Oil Drilling', 'stock' : 'DOLPHINOFF'},
{'sector' : 'Textiles', 'stock' : 'DONEAR'},
{'sector' : 'Petrochem', 'stock' : 'DPL'},
{'sector' : 'Power', 'stock' : 'DPSCLTD'},
{'sector' : 'Misc', 'stock' : 'DREDGECORP'},
{'sector' : 'Pharmaceuticals', 'stock' : 'DRREDDY'},
{'sector' : 'Tea-Coffee', 'stock' : 'DTIL'},
{'sector' : 'NA', 'stock' : 'DUCON'},
{'sector' : 'Sugar', 'stock' : 'DWARKESH'},
{'sector' : 'Misc', 'stock' : 'DYNAMATECH'},
{'sector' : 'Textiles', 'stock' : 'EASTSILK'},
{'sector' : 'Misc', 'stock' : 'ECEIND'},
{'sector' : 'Services', 'stock' : 'ECLERX'},
{'sector' : 'Finance', 'stock' : 'EDELWEISS'},
{'sector' : 'Beverages', 'stock' : 'EDL'},
{'sector' : 'Computers', 'stock' : 'EDUCOMP'},
{'sector' : 'Auto', 'stock' : 'EICHERMOT'},
{'sector' : 'Sugar', 'stock' : 'EIDPARRY'},
{'sector' : 'Hotels', 'stock' : 'EIHAHOTELS'},
{'sector' : 'Hotels', 'stock' : 'EIHOTEL'},
{'sector' : 'Engineering', 'stock' : 'EIMCOELECO'},
{'sector' : 'Packaging', 'stock' : 'EKC'},
{'sector' : 'Textiles', 'stock' : 'ELAND'},
{'sector' : 'Engineering', 'stock' : 'ELECON'},
{'sector' : 'Castings', 'stock' : 'ELECTCAST'},
{'sector' : 'Engineering', 'stock' : 'ELECTHERM'},
{'sector' : 'Compressors', 'stock' : 'ELGIEQUIP'},
{'sector' : 'Misc', 'stock' : 'ELGIRUBCO'},
{'sector' : 'FMCG', 'stock' : 'EMAMILTD'},
{'sector' : 'Electric', 'stock' : 'EMCO'},
{'sector' : 'Finance', 'stock' : 'EMKAY'},
{'sector' : 'Packaging', 'stock' : 'EMMBI'},
{'sector' : 'NA', 'stock' : 'ENDURANCE'},
{'sector' : 'Power', 'stock' : 'ENERGYDEV'},
{'sector' : 'Computers', 'stock' : 'ENGINERSIN'},
{'sector' : 'Entertainment', 'stock' : 'ENIL'},
{'sector' : 'Electric', 'stock' : 'EON'},
{'sector' : 'NA', 'stock' : 'EQUITAS'},
{'sector' : 'Entertainment', 'stock' : 'EROSMEDIA'},
{'sector' : 'Misc', 'stock' : 'ESABINDIA'},
{'sector' : 'Auto', 'stock' : 'ESCORTS'},
{'sector' : 'Steel', 'stock' : 'ESL'},
{'sector' : 'Shipping', 'stock' : 'ESSARSHPNG'},
{'sector' : 'Packaging', 'stock' : 'ESSELPACK'},
{'sector' : 'Packaging', 'stock' : 'ESTER'},
{'sector' : 'Textiles', 'stock' : 'EUROTEXIND'},
{'sector' : 'Dry Cells', 'stock' : 'EVEREADY'},
{'sector' : 'Cement', 'stock' : 'EVERESTIND'},
{'sector' : 'NA', 'stock' : 'EXCEL'},
{'sector' : 'Agro', 'stock' : 'EXCELCROP'},
{'sector' : 'Agro', 'stock' : 'EXCELINDUS'},
{'sector' : 'Auto Ancl', 'stock' : 'EXIDEIND'},
{'sector' : 'Fertilisers', 'stock' : 'FACT'},
{'sector' : 'Auto Ancl', 'stock' : 'FAGBEARING'},
{'sector' : 'NA', 'stock' : 'FAIRCHEM'},
{'sector' : 'Chemicals', 'stock' : 'FCL'},
{'sector' : 'NA', 'stock' : 'FCONSUMER'},
{'sector' : 'Pharmaceuticals', 'stock' : 'FDC'},
{'sector' : 'Air Conditioners', 'stock' : 'FEDDERLOYD'},
{'sector' : 'Banks - Private', 'stock' : 'FEDERALBNK'},
{'sector' : 'NA', 'stock' : 'FEL'},
{'sector' : 'NA', 'stock' : 'FELDVR'},
{'sector' : 'Auto Ancl', 'stock' : 'FIEMIND'},
{'sector' : 'Textiles', 'stock' : 'FILATEX'},
{'sector' : 'Cables', 'stock' : 'FINCABLES'},
{'sector' : 'Petrochem', 'stock' : 'FINPIPE'},
{'sector' : 'Packaging', 'stock' : 'FLEXITUFF'},
{'sector' : 'Textiles', 'stock' : 'FLFL'},
{'sector' : 'Auto Ancl', 'stock' : 'FMGOETZE'},
{'sector' : 'Misc', 'stock' : 'FMNL'},
{'sector' : 'Medical', 'stock' : 'FORTIS'},
{'sector' : 'Chemicals', 'stock' : 'FOSECOIND'},
{'sector' : 'NA', 'stock' : 'FRETAIL'},
{'sector' : 'Computers', 'stock' : 'FSL'},
{'sector' : 'Auto Ancl', 'stock' : 'GABRIEL'},
{'sector' : 'Edible Oils', 'stock' : 'GAEL'},
{'sector' : 'Oil Drilling', 'stock' : 'GAIL'},
{'sector' : 'Steel', 'stock' : 'GAL'},
{'sector' : 'Steel', 'stock' : 'GALLANTT'},
{'sector' : 'Steel', 'stock' : 'GALLISPAT'},
{'sector' : 'Infrastructure', 'stock' : 'GAMMNINFRA'},
{'sector' : 'Construction', 'stock' : 'GAMMONIND'},
{'sector' : 'Steel', 'stock' : 'GANDHITUBE'},
{'sector' : 'Textiles', 'stock' : 'GANECOS'},
{'sector' : 'Construction', 'stock' : 'GANESHHOUC'},
{'sector' : 'Textiles', 'stock' : 'GARDENSILK'},
{'sector' : 'Textiles', 'stock' : 'GARWALLROP'},
{'sector' : 'Couriers', 'stock' : 'GATI'},
{'sector' : 'Infrastructure', 'stock' : 'GAYAPROJ'},
{'sector' : 'Misc', 'stock' : 'GDL'},
{'sector' : 'Chemicals', 'stock' : 'GEECEE'},
{'sector' : 'Computers', 'stock' : 'GENESYS'},
{'sector' : 'Paper', 'stock' : 'GENUSPAPER'},
{'sector' : 'Electronics', 'stock' : 'GENUSPOWER'},
{'sector' : 'NA', 'stock' : 'GEOJITFSL'},
{'sector' : 'NA', 'stock' : 'GEPIL'},
{'sector' : 'Shipping', 'stock' : 'GESHIP'},
{'sector' : 'NA', 'stock' : 'GET&D'},
{'sector' : 'Chemicals', 'stock' : 'GHCL'},
{'sector' : 'Finance', 'stock' : 'GICHSGFIN'},
{'sector' : 'Diversified', 'stock' : 'GILLANDERS'},
{'sector' : 'FMCG', 'stock' : 'GILLETTE'},
{'sector' : 'Textiles', 'stock' : 'GINNIFILA'},
{'sector' : 'Power', 'stock' : 'GIPCL'},
{'sector' : 'Jewellery', 'stock' : 'GITANJALI'},
{'sector' : 'Misc', 'stock' : 'GKWLIMITED'},
{'sector' : 'Pharmaceuticals', 'stock' : 'GLAXO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'GLENMARK'},
{'sector' : 'Misc', 'stock' : 'GLOBALVECT'},
{'sector' : 'Shipping', 'stock' : 'GLOBOFFS'},
{'sector' : 'Beverages', 'stock' : 'GLOBUSSPR'},
{'sector' : 'Beverages', 'stock' : 'GMBREW'},
{'sector' : 'Mining', 'stock' : 'GMDCLTD'},
{'sector' : 'Infrastructure', 'stock' : 'GMRINFRA'},
{'sector' : 'NA', 'stock' : 'GNA'},
{'sector' : 'Fertilisers', 'stock' : 'GNFC'},
{'sector' : 'Petrochem', 'stock' : 'GOACARBON'},
{'sector' : 'Chemicals', 'stock' : 'GOCLCORP'},
{'sector' : 'Cigarettes', 'stock' : 'GODFRYPHLP'},
{'sector' : 'FMCG', 'stock' : 'GODREJCP'},
{'sector' : 'Chemicals', 'stock' : 'GODREJIND'},
{'sector' : 'Construction', 'stock' : 'GODREJPROP'},
{'sector' : 'Edible Oils', 'stock' : 'GOKUL'},
{'sector' : 'NA', 'stock' : 'GOKULAGRO'},
{'sector' : 'ETF', 'stock' : 'GOLDBEES'},
{'sector' : 'Jewellery', 'stock' : 'GOLDIAM'},
{'sector' : 'ETF', 'stock' : 'GOLDSHARE'},
{'sector' : 'Steel', 'stock' : 'GOODLUCK'},
{'sector' : 'Steel', 'stock' : 'GPIL'},
{'sector' : 'Shipping', 'stock' : 'GPPL'},
{'sector' : 'NA', 'stock' : 'GPTINFRA'},
{'sector' : 'Pharmaceuticals', 'stock' : 'GRANULES'},
{'sector' : 'Electronics', 'stock' : 'GRAPHITE'},
{'sector' : 'Diversified', 'stock' : 'GRASIM'},
{'sector' : 'Metals', 'stock' : 'GRAVITA'},
{'sector' : 'Engines', 'stock' : 'GREAVESCOT'},
{'sector' : 'Misc', 'stock' : 'GREENLAM'},
{'sector' : 'Consumer Goods', 'stock' : 'GREENPLY'},
{'sector' : 'Power', 'stock' : 'GREENPOWER'},
{'sector' : 'Grinding Wheels', 'stock' : 'GRINDWELL'},
{'sector' : 'NA', 'stock' : 'GROBTEA'},
{'sector' : 'Misc', 'stock' : 'GRPLTD'},
{'sector' : 'Finance', 'stock' : 'GRUH'},
{'sector' : 'Cement', 'stock' : 'GSCLCEMENT'},
{'sector' : 'Fertilisers', 'stock' : 'GSFC'},
{'sector' : 'Food Processing', 'stock' : 'GSKCONS'},
{'sector' : 'Petrochem', 'stock' : 'GSPL'},
{'sector' : 'Computers', 'stock' : 'GSS'},
{'sector' : 'Telecom', 'stock' : 'GTL'},
{'sector' : 'Telecom', 'stock' : 'GTLINFRA'},
{'sector' : 'Textiles', 'stock' : 'GTNIND'},
{'sector' : 'Shipping', 'stock' : 'GTOFFSHORE'},
{'sector' : 'Pharmaceuticals', 'stock' : 'GUFICBIO'},
{'sector' : 'Chemicals', 'stock' : 'GUJALKALI'},
{'sector' : 'Engineering', 'stock' : 'GUJAPOLLO'},
{'sector' : 'Chemicals', 'stock' : 'GUJFLUORO'},
{'sector' : 'Gas', 'stock' : 'GUJGASLTD'},
{'sector' : 'Coke', 'stock' : 'GUJNRECOKE'},
{'sector' : 'Coke', 'stock' : 'GUJNREDVR'},
{'sector' : 'Chemicals', 'stock' : 'GULFOILLUB'},
{'sector' : 'Chemicals', 'stock' : 'GULFPETRO'},
{'sector' : 'Chemicals', 'stock' : 'GULPOLY'},
{'sector' : 'Power', 'stock' : 'GVKPIL'},
{'sector' : 'Misc', 'stock' : 'HANUNG'},
{'sector' : 'Auto Ancl', 'stock' : 'HARITASEAT'},
{'sector' : 'Tea-Coffee', 'stock' : 'HARRMALAYA'},
{'sector' : 'Entertainment', 'stock' : 'HATHWAY'},
{'sector' : 'Food Processing', 'stock' : 'HATSUN'},
{'sector' : 'Electric', 'stock' : 'HAVELLS'},
{'sector' : 'Electric', 'stock' : 'HBLPOWER'},
{'sector' : 'Finance', 'stock' : 'HBSTOCK'},
{'sector' : 'Construction', 'stock' : 'HCC'},
{'sector' : 'NA', 'stock' : 'HCG'},
{'sector' : 'Computers', 'stock' : 'HCL-INSYS'},
{'sector' : 'Computers', 'stock' : 'HCLTECH'},
{'sector' : 'Finance', 'stock' : 'HDFC'},
{'sector' : 'Banks - Private', 'stock' : 'HDFCBANK'},
{'sector' : 'Construction', 'stock' : 'HDIL'},
{'sector' : 'Electronics', 'stock' : 'HEG'},
{'sector' : 'Cement', 'stock' : 'HEIDELBERG'},
{'sector' : 'Engineering', 'stock' : 'HERCULES'},
{'sector' : 'Food Processing', 'stock' : 'HERITGFOOD'},
{'sector' : 'Auto', 'stock' : 'HEROMOTOCO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'HESTERBIO'},
{'sector' : 'Trading', 'stock' : 'HEXATRADEX'},
{'sector' : 'Computers', 'stock' : 'HEXAWARE'},
{'sector' : 'Telecom', 'stock' : 'HFCL'},
{'sector' : 'Computers', 'stock' : 'HGS'},
{'sector' : 'NA', 'stock' : 'HIGHGROUND'},
{'sector' : 'Pharmaceuticals', 'stock' : 'HIKAL'},
{'sector' : 'Cement', 'stock' : 'HIL'},
{'sector' : 'Auto Ancl', 'stock' : 'HILTON'},
{'sector' : 'Textiles', 'stock' : 'HIMATSEIDE'},
{'sector' : 'Aluminium', 'stock' : 'HINDALCO'},
{'sector' : 'Auto Ancl', 'stock' : 'HINDCOMPOS'},
{'sector' : 'Metals', 'stock' : 'HINDCOPPER'},
{'sector' : 'Auto', 'stock' : 'HINDMOTORS'},
{'sector' : 'Glass', 'stock' : 'HINDNATGLS'},
{'sector' : 'Oil Drilling', 'stock' : 'HINDOILEXP'},
{'sector' : 'Refineries', 'stock' : 'HINDPETRO'},
{'sector' : 'Castings', 'stock' : 'HINDUJAFO'},
{'sector' : 'Computers', 'stock' : 'HINDUJAVEN'},
{'sector' : 'FMCG', 'stock' : 'HINDUNILVR'},
{'sector' : 'Metals', 'stock' : 'HINDZINC'},
{'sector' : 'Electronics', 'stock' : 'HIRECT'},
{'sector' : 'NA', 'stock' : 'HISARMETAL'},
{'sector' : 'Auto Ancl', 'stock' : 'HITECHGEAR'},
{'sector' : 'Printing', 'stock' : 'HMVL'},
{'sector' : 'Misc', 'stock' : 'HONAUT'},
{'sector' : 'Electric', 'stock' : 'HONDAPOWER'},
{'sector' : 'Hotels', 'stock' : 'HOTELEELA'},
{'sector' : 'Computers', 'stock' : 'HOVS'},
{'sector' : 'NA', 'stock' : 'HPL'},
{'sector' : 'NA', 'stock' : 'HSCL'},
{'sector' : 'Ceramics', 'stock' : 'HSIL'},
{'sector' : 'Printing', 'stock' : 'HTMEDIA'},
{'sector' : 'Construction', 'stock' : 'HUBTOWN'},
{'sector' : 'NA', 'stock' : 'HUDCO'},
{'sector' : 'Construction', 'stock' : 'IBREALEST'},
{'sector' : 'Finance', 'stock' : 'IBULHSGFIN'},
{'sector' : 'Finance', 'stock' : 'IBVENTURES'},
{'sector' : 'Banks - Private', 'stock' : 'ICICIBANK'},
{'sector' : 'NA', 'stock' : 'ICICIPRULI'},
{'sector' : 'Textiles', 'stock' : 'ICIL'},
{'sector' : 'Misc', 'stock' : 'ICRA'},
{'sector' : 'Computers', 'stock' : 'ICSA'},
{'sector' : 'Banks - PSU', 'stock' : 'IDBI'},
{'sector' : 'Telecom', 'stock' : 'IDEA'},
{'sector' : 'Finance', 'stock' : 'IDFC'},
{'sector' : 'Banks - Private', 'stock' : 'IDFCBANK'},
{'sector' : 'Chemicals', 'stock' : 'IFBAGRO'},
{'sector' : 'Consumer Goods', 'stock' : 'IFBIND'},
{'sector' : 'Finance', 'stock' : 'IFCI'},
{'sector' : 'Misc', 'stock' : 'IFGLREFRAC'},
{'sector' : 'Electric', 'stock' : 'IGARASHI'},
{'sector' : 'Gas', 'stock' : 'IGL'},
{'sector' : 'Chemicals', 'stock' : 'IGPL'},
{'sector' : 'Finance', 'stock' : 'IIFL'},
{'sector' : 'Finance', 'stock' : 'IITL'},
{'sector' : 'Construction', 'stock' : 'IL&FSENGG'},
{'sector' : 'Construction', 'stock' : 'IL&FSTRANS'},
{'sector' : 'Mining', 'stock' : 'IMFA'},
{'sector' : 'Auto Ancl', 'stock' : 'IMPAL'},
{'sector' : 'Misc', 'stock' : 'IMPEXFERRO'},
{'sector' : 'Finance', 'stock' : 'INDBANK'},
{'sector' : 'Hotels', 'stock' : 'INDHOTEL'},
{'sector' : 'Cement', 'stock' : 'INDIACEM'},
{'sector' : 'Chemicals', 'stock' : 'INDIAGLYCO'},
{'sector' : 'Banks - PSU', 'stock' : 'INDIANB'},
{'sector' : 'Textiles', 'stock' : 'INDIANCARD'},
{'sector' : 'Cement', 'stock' : 'INDIANHUME'},
{'sector' : 'Transport', 'stock' : 'INDIGO'},
{'sector' : 'Electric', 'stock' : 'INDLMETER'},
{'sector' : 'Auto Ancl', 'stock' : 'INDNIPPON'},
{'sector' : 'Pharmaceuticals', 'stock' : 'INDOCO'},
{'sector' : 'Textiles', 'stock' : 'INDORAMA'},
{'sector' : 'Misc', 'stock' : 'INDOSOLAR'},
{'sector' : 'Power', 'stock' : 'INDOTECH'},
{'sector' : 'Finance', 'stock' : 'INDOTHAI'},
{'sector' : 'Power', 'stock' : 'INDOWIND'},
{'sector' : 'Medical', 'stock' : 'INDRAMEDCO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'INDSWFTLAB'},
{'sector' : 'Textiles', 'stock' : 'INDTERRAIN'},
{'sector' : 'Banks - Private', 'stock' : 'INDUSINDBK'},
{'sector' : 'NA', 'stock' : 'INEOSSTYRO'},
{'sector' : 'NA', 'stock' : 'INFIBEAM'},
{'sector' : 'Computers', 'stock' : 'INFINITE'},
{'sector' : 'Transmisson Line Towers / Equipment', 'stock' : 'INFRATEL'},
{'sector' : 'Computers', 'stock' : 'INFY'},
{'sector' : 'Compressors', 'stock' : 'INGERRAND'},
{'sector' : 'Entertainment', 'stock' : 'INOXLEISUR'},
{'sector' : 'Electric', 'stock' : 'INOXWIND'},
{'sector' : 'Agro', 'stock' : 'INSECTICID'},
{'sector' : 'Computers', 'stock' : 'INTELLECT'},
{'sector' : 'NA', 'stock' : 'INTENTECH'},
{'sector' : 'Finance', 'stock' : 'INVENTURE'},
{'sector' : 'Banks - PSU', 'stock' : 'IOB'},
{'sector' : 'Refineries', 'stock' : 'IOC'},
{'sector' : 'Chemicals', 'stock' : 'IOLCP'},
{'sector' : 'Paper', 'stock' : 'IPAPPM'},
{'sector' : 'Pharmaceuticals', 'stock' : 'IPCALAB'},
{'sector' : 'Construction', 'stock' : 'IRB'},
{'sector' : 'Computers', 'stock' : 'ISFT'},
{'sector' : 'Steel', 'stock' : 'ISMTLTD'},
{'sector' : 'Cigarettes', 'stock' : 'ITC'},
{'sector' : 'NA', 'stock' : 'ITDC'},
{'sector' : 'Construction', 'stock' : 'ITDCEM'},
{'sector' : 'Telecom', 'stock' : 'ITI'},
{'sector' : 'Finance', 'stock' : 'IVC'},
{'sector' : 'Misc', 'stock' : 'IVP'},
{'sector' : 'Construction', 'stock' : 'IVRCLINFRA'},
{'sector' : 'Computers', 'stock' : 'IZMO'},
{'sector' : 'Banks - Private', 'stock' : 'J&KBANK'},
{'sector' : 'Printing', 'stock' : 'JAGRAN'},
{'sector' : 'Pharmaceuticals', 'stock' : 'JAGSNPHARM'},
{'sector' : 'Steel', 'stock' : 'JAIBALAJI'},
{'sector' : 'Steel', 'stock' : 'JAICORPLTD'},
{'sector' : 'Auto Ancl', 'stock' : 'JAMNAAUTO'},
{'sector' : 'Chemicals', 'stock' : 'JAYAGROGN'},
{'sector' : 'Auto Ancl', 'stock' : 'JAYBARMARU'},
{'sector' : 'Castings', 'stock' : 'JAYNECOIND'},
{'sector' : 'Tea-Coffee', 'stock' : 'JAYSREETEA'},
{'sector' : 'Pharmaceuticals', 'stock' : 'JBCHEPHARM'},
{'sector' : 'Textiles', 'stock' : 'JBFIND'},
{'sector' : 'Auto Ancl', 'stock' : 'JBMA'},
{'sector' : 'NA', 'stock' : 'JCHAC'},
{'sector' : 'Transport', 'stock' : 'JETAIRWAYS'},
{'sector' : 'Packaging', 'stock' : 'JINDALPOLY'},
{'sector' : 'Steel', 'stock' : 'JINDALSAW'},
{'sector' : 'Steel', 'stock' : 'JINDALSTEL'},
{'sector' : 'Textiles', 'stock' : 'JINDCOT'},
{'sector' : 'Oil Drilling', 'stock' : 'JINDRILL'},
{'sector' : 'Textiles', 'stock' : 'JINDWORLD'},
{'sector' : 'Plastics', 'stock' : 'JISLDVREQS'},
{'sector' : 'Misc', 'stock' : 'JISLJALEQS'},
{'sector' : 'Cement', 'stock' : 'JKCEMENT'},
{'sector' : 'Construction', 'stock' : 'JKIL'},
{'sector' : 'Cement', 'stock' : 'JKLAKSHMI'},
{'sector' : 'Paper', 'stock' : 'JKPAPER'},
{'sector' : 'Auto Ancl', 'stock' : 'JKTYRE'},
{'sector' : 'Auto Ancl', 'stock' : 'JMA'},
{'sector' : 'Construction', 'stock' : 'JMCPROJECT'},
{'sector' : 'Finance', 'stock' : 'JMFINANCIL'},
{'sector' : 'Auto Ancl', 'stock' : 'JMTAUTOLTD'},
{'sector' : 'Chemicals', 'stock' : 'JOCIL'},
{'sector' : 'Construction', 'stock' : 'JPASSOCIAT'},
{'sector' : 'Construction', 'stock' : 'JPINFRATEC'},
{'sector' : 'Finance', 'stock' : 'JPOLYINVST'},
{'sector' : 'Power', 'stock' : 'JPPOWER'},
{'sector' : 'Steel', 'stock' : 'JSL'},
{'sector' : 'NA', 'stock' : 'JSLHISAR'},
{'sector' : 'Power', 'stock' : 'JSWENERGY'},
{'sector' : 'Finance', 'stock' : 'JSWHL'},
{'sector' : 'Steel', 'stock' : 'JSWSTEEL'},
{'sector' : 'Pharmaceuticals', 'stock' : 'JUBILANT'},
{'sector' : 'Food Processing', 'stock' : 'JUBLFOOD'},
{'sector' : 'Agro', 'stock' : 'JUBLINDS'},
{'sector' : 'ETF', 'stock' : 'JUNIORBEES'},
{'sector' : 'Misc', 'stock' : 'JUSTDIAL'},
{'sector' : 'Edible Oils', 'stock' : 'JVLAGRO'},
{'sector' : 'FMCG', 'stock' : 'JYOTHYLAB'},
{'sector' : 'Power', 'stock' : 'JYOTISTRUC'},
{'sector' : 'Engineering', 'stock' : 'KABRAEXTRU'},
{'sector' : 'Ceramics', 'stock' : 'KAJARIACER'},
{'sector' : 'Cement', 'stock' : 'KAKATCEM'},
{'sector' : 'Power', 'stock' : 'KALPATPOWR'},
{'sector' : 'Hotels', 'stock' : 'KAMATHOTEL'},
{'sector' : 'NA', 'stock' : 'KAMDHENU'},
{'sector' : 'Jewellery', 'stock' : 'KANANIIND'},
{'sector' : 'Chemicals', 'stock' : 'KANORICHEM'},
{'sector' : 'Paints', 'stock' : 'KANSAINER'},
{'sector' : 'Power', 'stock' : 'KARMAENG'},
{'sector' : 'Banks - Private', 'stock' : 'KARURVYSYA'},
{'sector' : 'Construction', 'stock' : 'KAUSHALYA'},
{'sector' : 'Telecom', 'stock' : 'KAVVERITEL'},
{'sector' : 'Personal Care', 'stock' : 'KAYA'},
{'sector' : 'Cement', 'stock' : 'KCP'},
{'sector' : 'Sugar', 'stock' : 'KCPSUGIND'},
{'sector' : 'NA', 'stock' : 'KDDL'},
{'sector' : 'Power', 'stock' : 'KEC'},
{'sector' : 'Electric', 'stock' : 'KECL'},
{'sector' : 'Cables', 'stock' : 'KEI'},
{'sector' : 'Computers', 'stock' : 'KELLTONTEC'},
{'sector' : 'Sugar', 'stock' : 'KESARENT'},
{'sector' : 'Diversified', 'stock' : 'KESORAMIND'},
{'sector' : 'Finance', 'stock' : 'KEYCORPSER'},
{'sector' : 'Misc', 'stock' : 'KGL'},
{'sector' : 'Finance', 'stock' : 'KHANDSE'},
{'sector' : 'Finance', 'stock' : 'KICL'},
{'sector' : 'NA', 'stock' : 'KINGFA'},
{'sector' : 'NA', 'stock' : 'KIOCL'},
{'sector' : 'Dyes', 'stock' : 'KIRIINDUS'},
{'sector' : 'Misc', 'stock' : 'KIRLOSBROS'},
{'sector' : 'Engines', 'stock' : 'KIRLOSENG'},
{'sector' : 'Engines', 'stock' : 'KIRLOSIND'},
{'sector' : 'Textiles', 'stock' : 'KITEX'},
{'sector' : 'Retail', 'stock' : 'KKCL'},
{'sector' : 'Sugar', 'stock' : 'KMSUGAR'},
{'sector' : 'Construction', 'stock' : 'KNRCON'},
{'sector' : 'Commodities', 'stock' : 'KOHINOOR'},
{'sector' : 'Printing', 'stock' : 'KOKUYOCMLN'},
{'sector' : 'Construction', 'stock' : 'KOLTEPATIL'},
{'sector' : 'Pharmaceuticals', 'stock' : 'KOPRAN'},
{'sector' : 'Banks - Private', 'stock' : 'KOTAKBANK'},
{'sector' : 'ETF', 'stock' : 'KOTAKGOLD'},
{'sector' : 'ETF', 'stock' : 'KOTAKNIFTY'},
{'sector' : 'ETF', 'stock' : 'KOTAKPSUBK'},
{'sector' : 'Sugar', 'stock' : 'KOTARISUG'},
{'sector' : 'Trading', 'stock' : 'KOTHARIPET'},
{'sector' : 'Misc', 'stock' : 'KOTHARIPRO'},
{'sector' : 'Computers', 'stock' : 'KPIT'},
{'sector' : 'Textiles', 'stock' : 'KPRMILL'},
{'sector' : 'Commodities', 'stock' : 'KRBL'},
{'sector' : 'Misc', 'stock' : 'KSBPUMPS'},
{'sector' : 'Misc', 'stock' : 'KSCL'},
{'sector' : 'Steel', 'stock' : 'KSL'},
{'sector' : 'Misc', 'stock' : 'KTIL'},
{'sector' : 'Banks - Private', 'stock' : 'KTKBANK'},
{'sector' : 'Food Processing', 'stock' : 'KWALITY'},
{'sector' : 'Finance', 'stock' : 'L&TFH'},
{'sector' : 'Misc', 'stock' : 'LAKPRE'},
{'sector' : 'Commodities', 'stock' : 'LAKSHMIEFL'},
{'sector' : 'Banks - Private', 'stock' : 'LAKSHVILAS'},
{'sector' : 'Healthcare', 'stock' : 'LALPATHLAB'},
{'sector' : 'Textiles', 'stock' : 'LAMBODHARA'},
{'sector' : 'Glass', 'stock' : 'LAOPALA'},
{'sector' : 'NA', 'stock' : 'LAURUSLABS'},
{'sector' : 'Textiles', 'stock' : 'LAXMIMACH'},
{'sector' : 'Engineering', 'stock' : 'LGBBROSLTD'},
{'sector' : 'Leather', 'stock' : 'LIBERTSHOE'},
{'sector' : 'Finance', 'stock' : 'LICHSGFIN'},
{'sector' : 'Pharmaceuticals', 'stock' : 'LINCOLN'},
{'sector' : 'Printing', 'stock' : 'LINCPEN'},
{'sector' : 'Chemicals', 'stock' : 'LINDEINDIA'},
{'sector' : 'ETF', 'stock' : 'LIQUIDBEES'},
{'sector' : 'Infrastructure', 'stock' : 'LITL'},
{'sector' : 'Air Conditioners', 'stock' : 'LLOYDELENG'},
{'sector' : 'Auto', 'stock' : 'LML'},
{'sector' : 'Misc', 'stock' : 'LOKESHMACH'},
{'sector' : 'Medical', 'stock' : 'LOTUSEYE'},
{'sector' : 'Textiles', 'stock' : 'LOVABLE'},
{'sector' : 'Construction', 'stock' : 'LPDC'},
{'sector' : 'NA', 'stock' : 'LSIL'},
{'sector' : 'Diversified', 'stock' : 'LT'},
{'sector' : 'NA', 'stock' : 'LTI'},
{'sector' : 'NA', 'stock' : 'LTTS'},
{'sector' : 'Auto Ancl', 'stock' : 'LUMAXIND'},
{'sector' : 'Auto Ancl', 'stock' : 'LUMAXTECH'},
{'sector' : 'Pharmaceuticals', 'stock' : 'LUPIN'},
{'sector' : 'Textiles', 'stock' : 'LUXIND'},
{'sector' : 'Pharmaceuticals', 'stock' : 'LYKALABS'},
{'sector' : 'Jewellery', 'stock' : 'LYPSAGEMS'},
{'sector' : 'Auto', 'stock' : 'M&M'},
{'sector' : 'Finance', 'stock' : 'M&MFIN'},
{'sector' : 'Aluminium', 'stock' : 'MAANALU'},
{'sector' : 'Misc', 'stock' : 'MADHAV'},
{'sector' : 'Construction', 'stock' : 'MADHUCON'},
{'sector' : 'Finance', 'stock' : 'MAGMA'},
{'sector' : 'Paper', 'stock' : 'MAGNUM'},
{'sector' : 'Banks - PSU', 'stock' : 'MAHABANK'},
{'sector' : 'NA', 'stock' : 'MAHASTEEL'},
{'sector' : 'Castings', 'stock' : 'MAHINDCIE'},
{'sector' : 'Construction', 'stock' : 'MAHLIFE'},
{'sector' : 'Auto', 'stock' : 'MAHSCOOTER'},
{'sector' : 'Steel', 'stock' : 'MAHSEAMLES'},
{'sector' : 'Mining', 'stock' : 'MAITHANALL'},
{'sector' : 'Computers', 'stock' : 'MAJESCO'},
{'sector' : 'Paper', 'stock' : 'MALUPAPER'},
{'sector' : 'Steel', 'stock' : 'MANAKCOAT'},
{'sector' : 'Packaging', 'stock' : 'MANAKSIA'},
{'sector' : 'Steel', 'stock' : 'MANAKSTEEL'},
{'sector' : 'Petrochem', 'stock' : 'MANALIPETC'},
{'sector' : 'Finance', 'stock' : 'MANAPPURAM'},
{'sector' : 'Textiles', 'stock' : 'MANDHANA'},
{'sector' : 'Pharmaceuticals', 'stock' : 'MANGALAM'},
{'sector' : 'Fertilisers', 'stock' : 'MANGCHEFER'},
{'sector' : 'Cement', 'stock' : 'MANGLMCEM'},
{'sector' : 'Consumer Goods', 'stock' : 'MANGTIMBER'},
{'sector' : 'Steel', 'stock' : 'MANINDS'},
{'sector' : 'Construction', 'stock' : 'MANINFRA'},
{'sector' : 'Food Processing', 'stock' : 'MANPASAND'},
{'sector' : 'Engineering', 'stock' : 'MANUGRAPH'},
{'sector' : 'Textiles', 'stock' : 'MARALOVER'},
{'sector' : 'NA', 'stock' : 'MARATHON'},
{'sector' : 'FMCG', 'stock' : 'MARICO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'MARKSANS'},
{'sector' : 'Auto', 'stock' : 'MARUTI'},
{'sector' : 'Computers', 'stock' : 'MASTEK'},
{'sector' : 'Sugar', 'stock' : 'MAWANASUG'},
{'sector' : 'NA', 'stock' : 'MAXINDIA'},
{'sector' : 'NA', 'stock' : 'MAXVIL'},
{'sector' : 'Plastics', 'stock' : 'MAYURUNIQ'},
{'sector' : 'NA', 'stock' : 'MAZDA'},
{'sector' : 'Engineering', 'stock' : 'MBECL'},
{'sector' : 'Construction', 'stock' : 'MBLINFRA'},
{'sector' : 'NA', 'stock' : 'MCDHOLDING'},
{'sector' : 'Beverages', 'stock' : 'MCDOWELL-N'},
{'sector' : 'Tea-Coffee', 'stock' : 'MCLEODRUSS'},
{'sector' : 'Misc', 'stock' : 'MCX'},
{'sector' : 'Computers', 'stock' : 'MEGASOFT'},
{'sector' : 'Agro', 'stock' : 'MEGH'},
{'sector' : 'NA', 'stock' : 'MENONBE'},
{'sector' : 'Construction', 'stock' : 'MEP'},
{'sector' : 'Shipping', 'stock' : 'MERCATOR'},
{'sector' : 'Pharmaceuticals', 'stock' : 'MERCK'},
{'sector' : 'Castings', 'stock' : 'METALFORGE'},
{'sector' : 'Packaging', 'stock' : 'MFSL'},
{'sector' : 'NA', 'stock' : 'MGL'},
{'sector' : 'Hotels', 'stock' : 'MHRIL'},
{'sector' : 'Electronics', 'stock' : 'MIC'},
{'sector' : 'Auto Ancl', 'stock' : 'MINDACORP'},
{'sector' : 'Auto Ancl', 'stock' : 'MINDAIND'},
{'sector' : 'NA', 'stock' : 'MINDTECK'},
{'sector' : 'Computers', 'stock' : 'MINDTREE'},
{'sector' : 'Consumer Goods', 'stock' : 'MIRCELECTR'},
{'sector' : 'Leather', 'stock' : 'MIRZAINT'},
{'sector' : 'Auto Ancl', 'stock' : 'MMFL'},
{'sector' : 'Trading', 'stock' : 'MMTC'},
{'sector' : 'Textiles', 'stock' : 'MOHITIND'},
{'sector' : 'NA', 'stock' : 'MOIL'},
{'sector' : 'NA', 'stock' : 'MOLDTECH'},
{'sector' : 'Plastics', 'stock' : 'MOLDTKPAC'},
{'sector' : 'Steel', 'stock' : 'MONNETISPA'},
{'sector' : 'Agro', 'stock' : 'MONSANTO'},
{'sector' : 'Textiles', 'stock' : 'MONTECARLO'},
{'sector' : 'Textiles', 'stock' : 'MORARJEE'},
{'sector' : 'Pharmaceuticals', 'stock' : 'MOREPENLAB'},
{'sector' : 'Computers', 'stock' : 'MOSERBAER'},
{'sector' : 'Auto Ancl', 'stock' : 'MOTHERSUMI'},
{'sector' : 'Finance', 'stock' : 'MOTILALOFS'},
{'sector' : 'Computers', 'stock' : 'MPHASIS'},
{'sector' : 'Printing', 'stock' : 'MPSLTD'},
{'sector' : 'Auto Ancl', 'stock' : 'MRF'},
{'sector' : 'Computers', 'stock' : 'MRO-TEK'},
{'sector' : 'Refineries', 'stock' : 'MRPL'},
{'sector' : 'Steel', 'stock' : 'MSPL'},
{'sector' : 'Misc', 'stock' : 'MTEDUCARE'},
{'sector' : 'Telecom', 'stock' : 'MTNL'},
{'sector' : 'Computers', 'stock' : 'MUKANDENGG'},
{'sector' : 'Steel', 'stock' : 'MUKANDLTD'},
{'sector' : 'Entertainment', 'stock' : 'MUKTAARTS'},
{'sector' : 'Auto Ancl', 'stock' : 'MUNJALAU'},
{'sector' : 'Auto Ancl', 'stock' : 'MUNJALSHOW'},
{'sector' : 'Finance', 'stock' : 'MUTHOOTCAP'},
{'sector' : 'Finance', 'stock' : 'MUTHOOTFIN'},
{'sector' : 'Construction', 'stock' : 'MVL'},
{'sector' : 'NA', 'stock' : 'NAGAAGRI'},
{'sector' : 'NA', 'stock' : 'NAGAFERT'},
{'sector' : 'Refineries', 'stock' : 'NAGAROIL'},
{'sector' : 'Finance', 'stock' : 'NAGREEKCAP'},
{'sector' : 'Textiles', 'stock' : 'NAGREEKEXP'},
{'sector' : 'Finance', 'stock' : 'NAHARCAP'},
{'sector' : 'Textiles', 'stock' : 'NAHARINDUS'},
{'sector' : 'Textiles', 'stock' : 'NAHARPOLY'},
{'sector' : 'Textiles', 'stock' : 'NAHARSPING'},
{'sector' : 'Pharmaceuticals', 'stock' : 'NATCOPHARM'},
{'sector' : 'Misc', 'stock' : 'NATHBIOGEN'},
{'sector' : 'Aluminium', 'stock' : 'NATIONALUM'},
{'sector' : 'Misc', 'stock' : 'NAUKRI'},
{'sector' : 'Chemicals', 'stock' : 'NAVINFLUOR'},
{'sector' : 'Misc', 'stock' : 'NAVKARCORP'},
{'sector' : 'Printing', 'stock' : 'NAVNETEDUL'},
{'sector' : 'Construction', 'stock' : 'NBCC'},
{'sector' : 'Diversified', 'stock' : 'NBVENTURES'},
{'sector' : 'Construction', 'stock' : 'NCC'},
{'sector' : 'Cement', 'stock' : 'NCLIND'},
{'sector' : 'NA', 'stock' : 'NDGL'},
{'sector' : 'Textiles', 'stock' : 'NDL'},
{'sector' : 'Entertainment', 'stock' : 'NDTV'},
{'sector' : 'Misc', 'stock' : 'NECCLTD'},
{'sector' : 'Pharmaceuticals', 'stock' : 'NECLIFE'},
{'sector' : 'Castings', 'stock' : 'NELCAST'},
{'sector' : 'Telecom', 'stock' : 'NELCO'},
{'sector' : 'Diversified', 'stock' : 'NESCO'},
{'sector' : 'Food Processing', 'stock' : 'NESTLEIND'},
{'sector' : 'Finance', 'stock' : 'NETWORK18'},
{'sector' : 'Pharmaceuticals', 'stock' : 'NEULANDLAB'},
{'sector' : 'Fertilisers', 'stock' : 'NFL'},
{'sector' : 'Medical', 'stock' : 'NH'},
{'sector' : 'Power', 'stock' : 'NHPC'},
{'sector' : 'NA', 'stock' : 'NIBL'},
{'sector' : 'Index', 'stock' : 'NIFTY'},
{'sector' : 'ETF', 'stock' : 'NIFTYBEES'},
{'sector' : 'Index', 'stock' : 'NIFTYINFRA'},
{'sector' : 'Index', 'stock' : 'NIFTYIT'},
{'sector' : 'Index', 'stock' : 'NIFTYMID50'},
{'sector' : 'Index', 'stock' : 'NIFTYPSE'},
{'sector' : 'Computers', 'stock' : 'NIITLTD'},
{'sector' : 'Computers', 'stock' : 'NIITTECH'},
{'sector' : 'Construction', 'stock' : 'NILAINFRA'},
{'sector' : 'Plastics', 'stock' : 'NILKAMAL'},
{'sector' : 'Dry Cells', 'stock' : 'NIPPOBATRY'},
{'sector' : 'Ceramics', 'stock' : 'NITCO'},
{'sector' : 'Construction', 'stock' : 'NITESHEST'},
{'sector' : 'Engineering', 'stock' : 'NITINFIRE'},
{'sector' : 'Textiles', 'stock' : 'NITINSPIN'},
{'sector' : 'NA', 'stock' : 'NKIND'},
{'sector' : 'NA', 'stock' : 'NLCINDIA'},
{'sector' : 'Mining', 'stock' : 'NMDC'},
{'sector' : 'Petrochem', 'stock' : 'NOCIL'},
{'sector' : 'Construction', 'stock' : 'NOIDATOLL'},
{'sector' : 'NA', 'stock' : 'NRAIL'},
{'sector' : 'Auto Ancl', 'stock' : 'NRBBEARING'},
{'sector' : 'Finance', 'stock' : 'NSIL'},
{'sector' : 'NA', 'stock' : 'NTL'},
{'sector' : 'Power', 'stock' : 'NTPC'},
{'sector' : 'Computers', 'stock' : 'NUCLEUS'},
{'sector' : 'Telecom', 'stock' : 'NUTEK'},
{'sector' : 'Construction', 'stock' : 'OBEROIRLTY'},
{'sector' : 'Chemicals', 'stock' : 'OCCL'},
{'sector' : 'Cement', 'stock' : 'OCL'},
{'sector' : 'Computers', 'stock' : 'OFSS'},
{'sector' : 'Oil Drilling', 'stock' : 'OIL'},
{'sector' : 'Steel', 'stock' : 'OILCOUNTUB'},
{'sector' : 'Auto Ancl', 'stock' : 'OMAXAUTO'},
{'sector' : 'Construction', 'stock' : 'OMAXE'},
{'sector' : 'Chemicals', 'stock' : 'OMKARCHEM'},
{'sector' : 'NA', 'stock' : 'OMMETALS'},
{'sector' : 'Oil Drilling', 'stock' : 'ONGC'},
{'sector' : 'Telecom', 'stock' : 'ONMOBILE'},
{'sector' : 'Medical', 'stock' : 'OPTOCIRCUI'},
{'sector' : 'NA', 'stock' : 'ORBTEXP'},
{'sector' : 'NA', 'stock' : 'ORCHIDPHAR'},
{'sector' : 'NA', 'stock' : 'ORICONENT'},
{'sector' : 'Grinding Wheels', 'stock' : 'ORIENTABRA'},
{'sector' : 'Banks - PSU', 'stock' : 'ORIENTBANK'},
{'sector' : 'NA', 'stock' : 'ORIENTBELL'},
{'sector' : 'NA', 'stock' : 'ORIENTCEM'},
{'sector' : 'Hotels', 'stock' : 'ORIENTHOT'},
{'sector' : 'NA', 'stock' : 'ORIENTLTD'},
{'sector' : 'Diversified', 'stock' : 'ORIENTPPR'},
{'sector' : 'NA', 'stock' : 'ORIENTREF'},
{'sector' : 'Mining', 'stock' : 'ORISSAMINE'},
{'sector' : 'NA', 'stock' : 'ORTEL'},
{'sector' : 'Textiles', 'stock' : 'PAGEIND'},
{'sector' : 'Pharmaceuticals', 'stock' : 'PANACEABIO'},
{'sector' : 'NA', 'stock' : 'PANAMAPET'},
{'sector' : 'Computers', 'stock' : 'PANORAMUNI'},
{'sector' : 'Packaging', 'stock' : 'PAPERPROD'},
{'sector' : 'Pharmaceuticals', 'stock' : 'PARABDRUGS'},
{'sector' : 'NA', 'stock' : 'PARAGMILK'},
{'sector' : 'Diversified', 'stock' : 'PARRYSUGAR'},
{'sector' : 'Construction', 'stock' : 'PARSVNATH'},
{'sector' : 'Construction', 'stock' : 'PATELENG'},
{'sector' : 'Transport', 'stock' : 'PATINTLOG'},
{'sector' : 'Textiles', 'stock' : 'PATSPINLTD'},
{'sector' : 'Infrastructure', 'stock' : 'PBAINFRA'},
{'sector' : 'NA', 'stock' : 'PCJEWELLER'},
{'sector' : 'NA', 'stock' : 'PDMJEPAPER'},
{'sector' : 'Pharmaceuticals', 'stock' : 'PDPL'},
{'sector' : 'NA', 'stock' : 'PDSMFL'},
{'sector' : 'Paper', 'stock' : 'PDUMJEIND'},
{'sector' : 'Paper', 'stock' : 'PDUMJEPULP'},
{'sector' : 'NA', 'stock' : 'PEL'},
{'sector' : 'Steel', 'stock' : 'PENIND'},
{'sector' : 'Construction', 'stock' : 'PENINLAND'},
{'sector' : 'NA', 'stock' : 'PENPEBS'},
{'sector' : 'Computers', 'stock' : 'PERSISTENT'},
{'sector' : 'Petrochem', 'stock' : 'PETRONET'},
{'sector' : 'Finance', 'stock' : 'PFC'},
{'sector' : 'Pharmaceuticals', 'stock' : 'PFIZER'},
{'sector' : 'Entertainment', 'stock' : 'PFOCUS'},
{'sector' : 'NA', 'stock' : 'PFS'},
{'sector' : 'NA', 'stock' : 'PGEL'},
{'sector' : 'FMCG', 'stock' : 'PGHH'},
{'sector' : 'NA', 'stock' : 'PGIL'},
{'sector' : 'Misc', 'stock' : 'PHILIPCARB'},
{'sector' : 'NA', 'stock' : 'PHOENIXLL'},
{'sector' : 'Construction', 'stock' : 'PHOENIXLTD'},
{'sector' : 'Chemicals', 'stock' : 'PIDILITIND'},
{'sector' : 'NA', 'stock' : 'PIIND'},
{'sector' : 'NA', 'stock' : 'PINCON'},
{'sector' : 'Beverages', 'stock' : 'PIONDIST'},
{'sector' : 'Textiles', 'stock' : 'PIONEEREMB'},
{'sector' : 'Engineering', 'stock' : 'PITTILAM'},
{'sector' : 'NA', 'stock' : 'PKTEA'},
{'sector' : 'Plastics', 'stock' : 'PLASTIBLEN'},
{'sector' : 'Banks - PSU', 'stock' : 'PNB'},
{'sector' : 'Finance', 'stock' : 'PNBGILTS'},
{'sector' : 'NA', 'stock' : 'PNBHOUSING'},
{'sector' : 'NA', 'stock' : 'PNCINFRA'},
{'sector' : 'NA', 'stock' : 'POCHIRAJU'},
{'sector' : 'NA', 'stock' : 'PODDARHOUS'},
{'sector' : 'NA', 'stock' : 'PODDARMENT'},
{'sector' : 'NA', 'stock' : 'POKARNA'},
{'sector' : 'Computers', 'stock' : 'POLARIS'},
{'sector' : 'NA', 'stock' : 'POLYMED'},
{'sector' : 'Packaging', 'stock' : 'POLYPLEX'},
{'sector' : 'Sugar', 'stock' : 'PONNIERODE'},
{'sector' : 'Power', 'stock' : 'POWERGRID'},
{'sector' : 'NA', 'stock' : 'POWERMECH'},
{'sector' : 'Plastics', 'stock' : 'PPAP'},
{'sector' : 'NA', 'stock' : 'PRABHAT'},
{'sector' : 'Construction', 'stock' : 'PRAENG'},
{'sector' : 'Engineering', 'stock' : 'PRAJIND'},
{'sector' : 'Diversified', 'stock' : 'PRAKASH'},
{'sector' : 'NA', 'stock' : 'PRAKASHCON'},
{'sector' : 'NA', 'stock' : 'PRAKASHSTL'},
{'sector' : 'Infrastructure', 'stock' : 'PRATIBHA'},
{'sector' : 'NA', 'stock' : 'PRECAM'},
{'sector' : 'Metals', 'stock' : 'PRECWIRE'},
{'sector' : 'NA', 'stock' : 'PREMEXPLN'},
{'sector' : 'Engineering', 'stock' : 'PREMIER'},
{'sector' : 'NA', 'stock' : 'PREMIERPOL'},
{'sector' : 'NA', 'stock' : 'PRESSMN'},
{'sector' : 'NA', 'stock' : 'PRESTIGE'},
{'sector' : 'NA', 'stock' : 'PRICOLLTD'},
{'sector' : 'Finance', 'stock' : 'PRIMESECU'},
{'sector' : 'Cement', 'stock' : 'PRISMCEM'},
{'sector' : 'NA', 'stock' : 'PROVOGE'},
{'sector' : 'NA', 'stock' : 'PROZONINTU'},
{'sector' : 'Banks - PSU', 'stock' : 'PSB'},
{'sector' : 'Steel', 'stock' : 'PSL'},
{'sector' : 'ETF', 'stock' : 'PSUBNKBEES'},
{'sector' : 'Power', 'stock' : 'PTC'},
{'sector' : 'Auto Ancl', 'stock' : 'PTL'},
{'sector' : 'Chemicals', 'stock' : 'PUNJABCHEM'},
{'sector' : 'Construction', 'stock' : 'PUNJLLOYD'},
{'sector' : 'Construction', 'stock' : 'PURVA'},
{'sector' : 'Entertainment', 'stock' : 'PVR'},
{'sector' : 'ETF', 'stock' : 'QGOLDHALF'},
{'sector' : 'ETF', 'stock' : 'QNIFTY'},
{'sector' : 'NA', 'stock' : 'QUESS'},
{'sector' : 'NA', 'stock' : 'QUICKHEAL'},
{'sector' : 'Finance', 'stock' : 'RADICO'},
{'sector' : 'NA', 'stock' : 'RADIOCITY'},
{'sector' : 'NA', 'stock' : 'RAIN'},
{'sector' : 'Paper', 'stock' : 'RAINBOWPAP'},
{'sector' : 'NA', 'stock' : 'RAIREKMOH'},
{'sector' : 'Jewellery', 'stock' : 'RAJESHEXPO'},
{'sector' : 'Sugar', 'stock' : 'RAJSREESUG'},
{'sector' : 'Entertainment', 'stock' : 'RAJTV'},
{'sector' : 'NA', 'stock' : 'RAJVIR'},
{'sector' : 'Agro', 'stock' : 'RALLIS'},
{'sector' : 'Paper', 'stock' : 'RAMANEWS'},
{'sector' : 'NA', 'stock' : 'RAMASTEEL'},
{'sector' : 'NA', 'stock' : 'RAMCOCEM'},
{'sector' : 'Cement', 'stock' : 'RAMCOIND'},
{'sector' : 'Computers', 'stock' : 'RAMCOSYS'},
{'sector' : 'Construction', 'stock' : 'RAMKY'},
{'sector' : 'Sugar', 'stock' : 'RANASUG'},
{'sector' : 'Auto Ancl', 'stock' : 'RANEENGINE'},
{'sector' : 'Finance', 'stock' : 'RANEHOLDIN'},
{'sector' : 'Steel', 'stock' : 'RATNAMANI'},
{'sector' : 'Textiles', 'stock' : 'RAYMOND'},
{'sector' : 'Auto Ancl', 'stock' : 'RBL'},
{'sector' : 'NA', 'stock' : 'RBLBANK'},
{'sector' : 'Fertilisers', 'stock' : 'RCF'},
{'sector' : 'Telecom', 'stock' : 'RCOM'},
{'sector' : 'NA', 'stock' : 'RDEL'},
{'sector' : 'Finance', 'stock' : 'RECLTD'},
{'sector' : 'NA', 'stock' : 'REDINGTON'},
{'sector' : 'NA', 'stock' : 'REFEX'},
{'sector' : 'Food Processing', 'stock' : 'REIAGROLTD'},
{'sector' : 'NA', 'stock' : 'RELAXO'},
{'sector' : 'Finance', 'stock' : 'RELCAPITAL'},
{'sector' : 'Diversified', 'stock' : 'RELIANCE'},
{'sector' : 'NA', 'stock' : 'RELIGARE'},
{'sector' : 'Power', 'stock' : 'RELINFRA'},
{'sector' : 'Auto Ancl', 'stock' : 'REMSONSIND'},
{'sector' : 'Sugar', 'stock' : 'RENUKA'},
{'sector' : 'NA', 'stock' : 'REPCOHOME'},
{'sector' : 'Printing', 'stock' : 'REPRO'},
{'sector' : 'Plastics', 'stock' : 'RESPONIND'},
{'sector' : 'Compressors', 'stock' : 'REVATHI'},
{'sector' : 'Auto Ancl', 'stock' : 'RICOAUTO'},
{'sector' : 'Computers', 'stock' : 'RIIL'},
{'sector' : 'Jewellery', 'stock' : 'RJL'},
{'sector' : 'NA', 'stock' : 'RKDL'},
{'sector' : 'NA', 'stock' : 'RKFORGE'},
{'sector' : 'NA', 'stock' : 'RML'},
{'sector' : 'Misc', 'stock' : 'ROHITFERRO'},
{'sector' : 'Hotels', 'stock' : 'ROHLTD'},
{'sector' : 'NA', 'stock' : 'ROLLT'},
{'sector' : 'Computers', 'stock' : 'ROLTA'},
{'sector' : 'NA', 'stock' : 'ROSSELLIND'},
{'sector' : 'NA', 'stock' : 'RPGLIFE'},
{'sector' : 'Power', 'stock' : 'RPOWER'},
{'sector' : 'Construction', 'stock' : 'RPPINFRA'},
{'sector' : 'Computers', 'stock' : 'RSSOFTWARE'},
{'sector' : 'Textiles', 'stock' : 'RSWM'},
{'sector' : 'Computers', 'stock' : 'RSYSTEMS'},
{'sector' : 'NA', 'stock' : 'RTNINFRA'},
{'sector' : 'NA', 'stock' : 'RTNPOWER'},
{'sector' : 'Textiles', 'stock' : 'RUBYMILLS'},
{'sector' : 'Paper', 'stock' : 'RUCHIRA'},
{'sector' : 'Edible Oils', 'stock' : 'RUCHISOYA'},
{'sector' : 'NA', 'stock' : 'RUPA'},
{'sector' : 'NA', 'stock' : 'RUSHIL'},
{'sector' : 'NA', 'stock' : 'SABEVENTS'},
{'sector' : 'Entertainment', 'stock' : 'SABTN'},
{'sector' : 'Construction', 'stock' : 'SADBHAV'},
{'sector' : 'NA', 'stock' : 'SADBHIN'},
{'sector' : 'Cement', 'stock' : 'SAGCEM'},
{'sector' : 'Steel', 'stock' : 'SAIL'},
{'sector' : 'Sugar', 'stock' : 'SAKHTISUG'},
{'sector' : 'Computers', 'stock' : 'SAKSOFT'},
{'sector' : 'Trading', 'stock' : 'SAKUMA'},
{'sector' : 'Consumer Goods', 'stock' : 'SALORAINTL'},
{'sector' : 'NA', 'stock' : 'SALZERELEC'},
{'sector' : 'Printing', 'stock' : 'SANDESH'},
{'sector' : 'Textiles', 'stock' : 'SANGAMIND'},
{'sector' : 'Cement', 'stock' : 'SANGHIIND'},
{'sector' : 'NA', 'stock' : 'SANGHVIFOR'},
{'sector' : 'Engineering', 'stock' : 'SANGHVIMOV'},
{'sector' : 'NA', 'stock' : 'SANOFI'},
{'sector' : 'Edible Oils', 'stock' : 'SANWARIA'},
{'sector' : 'Steel', 'stock' : 'SARDAEN'},
{'sector' : 'Entertainment', 'stock' : 'SAREGAMA'},
{'sector' : 'Textiles', 'stock' : 'SARLAPOLY'},
{'sector' : 'Computers', 'stock' : 'SASKEN'},
{'sector' : 'Steel', 'stock' : 'SATHAISPAT'},
{'sector' : 'NA', 'stock' : 'SATIN'},
{'sector' : 'Banks - PSU', 'stock' : 'SBIN'},
{'sector' : 'NA', 'stock' : 'SCHAND'},
{'sector' : 'NA', 'stock' : 'SCHNEIDER'},
{'sector' : 'Shipping', 'stock' : 'SCI'},
{'sector' : 'NA', 'stock' : 'SDBL'},
{'sector' : 'Shipping', 'stock' : 'SEAMECLTD'},
{'sector' : 'NA', 'stock' : 'SEINV'},
{'sector' : 'Oil Drilling', 'stock' : 'SELAN'},
{'sector' : 'Textiles', 'stock' : 'SELMCL'},
{'sector' : 'NA', 'stock' : 'SEPOWER'},
{'sector' : 'NA', 'stock' : 'SEQUENT'},
{'sector' : 'NA', 'stock' : 'SERVALL'},
{'sector' : 'Paper', 'stock' : 'SESHAPAPER'},
{'sector' : 'NA', 'stock' : 'SETCO'},
{'sector' : 'NA', 'stock' : 'SFL'},
{'sector' : 'Textiles', 'stock' : 'SGL'},
{'sector' : 'NA', 'stock' : 'SHAKTIPUMP'},
{'sector' : 'Paints', 'stock' : 'SHALPAINTS'},
{'sector' : 'NA', 'stock' : 'SHANKARA'},
{'sector' : 'Engineering', 'stock' : 'SHANTIGEAR'},
{'sector' : 'NA', 'stock' : 'SHARDACROP'},
{'sector' : 'NA', 'stock' : 'SHARDAMOTR'},
{'sector' : 'ETF', 'stock' : 'SHARIABEES'},
{'sector' : 'NA', 'stock' : 'SHARONBIO'},
{'sector' : 'NA', 'stock' : 'SHEMAROO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'SHILPAMED'},
{'sector' : 'NA', 'stock' : 'SHILPI'},
{'sector' : 'NA', 'stock' : 'SHIRPUR-G'},
{'sector' : 'Auto Ancl', 'stock' : 'SHIVAMAUTO'},
{'sector' : 'Textiles', 'stock' : 'SHIVTEX'},
{'sector' : 'NA', 'stock' : 'SHK'},
{'sector' : 'Retail', 'stock' : 'SHOPERSTOP'},
{'sector' : 'Cement', 'stock' : 'SHREECEM'},
{'sector' : 'NA', 'stock' : 'SHREEPUSHK'},
{'sector' : 'Packaging', 'stock' : 'SHREERAMA'},
{'sector' : 'Paper', 'stock' : 'SHREYANIND'},
{'sector' : 'Shipping', 'stock' : 'SHREYAS'},
{'sector' : 'NA', 'stock' : 'SHRIRAMCIT'},
{'sector' : 'Computers', 'stock' : 'SHRIRAMEPC'},
{'sector' : 'NA', 'stock' : 'SHYAMCENT'},
{'sector' : 'Telecom', 'stock' : 'SHYAMTEL'},
{'sector' : 'Trading', 'stock' : 'SICAGEN'},
{'sector' : 'Trading', 'stock' : 'SICAL'},
{'sector' : 'Misc', 'stock' : 'SIEMENS'},
{'sector' : 'NA', 'stock' : 'SIGNET'},
{'sector' : 'Finance', 'stock' : 'SILINV'},
{'sector' : 'NA', 'stock' : 'SIMBHALS'},
{'sector' : 'Construction', 'stock' : 'SIMPLEXINF'},
{'sector' : 'Diversified', 'stock' : 'SINTEX'},
{'sector' : 'Food Processing', 'stock' : 'SITASHREE'},
{'sector' : 'NA', 'stock' : 'SITINET'},
{'sector' : 'Textiles', 'stock' : 'SIYSIL'},
{'sector' : 'Power', 'stock' : 'SJVN'},
{'sector' : 'Auto Ancl', 'stock' : 'SKFINDIA'},
{'sector' : 'NA', 'stock' : 'SKIL'},
{'sector' : 'NA', 'stock' : 'SKIPPER'},
{'sector' : 'NA', 'stock' : 'SMARTLINK'},
{'sector' : 'Auto', 'stock' : 'SMLISUZU'},
{'sector' : 'NA', 'stock' : 'SMPL'},
{'sector' : 'Pharmaceuticals', 'stock' : 'SMSPHARMA'},
{'sector' : 'NA', 'stock' : 'SNOWMAN'},
{'sector' : 'Construction', 'stock' : 'SOBHA'},
{'sector' : 'Misc', 'stock' : 'SOLARINDS'},
{'sector' : 'Ceramics', 'stock' : 'SOMANYCERA'},
{'sector' : 'NA', 'stock' : 'SOMICONVEY'},
{'sector' : 'Auto Ancl', 'stock' : 'SONASTEER'},
{'sector' : 'Computers', 'stock' : 'SONATSOFTW'},
{'sector' : 'NA', 'stock' : 'SORILHOLD'},
{'sector' : 'NA', 'stock' : 'SORILINFRA'},
{'sector' : 'Petrochem', 'stock' : 'SOTL'},
{'sector' : 'Banks - Private', 'stock' : 'SOUTHBANK'},
{'sector' : 'NA', 'stock' : 'SPAL'},
{'sector' : 'Misc', 'stock' : 'SPARC'},
{'sector' : 'NA', 'stock' : 'SPCENET'},
{'sector' : 'Textiles', 'stock' : 'SPENTEX'},
{'sector' : 'NA', 'stock' : 'SPHEREGSL'},
{'sector' : 'Fertilisers', 'stock' : 'SPIC'},
{'sector' : 'NA', 'stock' : 'SPICEMOBI'},
{'sector' : 'Textiles', 'stock' : 'SPLIL'},
{'sector' : 'NA', 'stock' : 'SPYL'},
{'sector' : 'NA', 'stock' : 'SQSBFSI'},
{'sector' : 'NA', 'stock' : 'SREEL'},
{'sector' : 'Finance', 'stock' : 'SREINFRA'},
{'sector' : 'Textiles', 'stock' : 'SRF'},
{'sector' : 'Petrochem', 'stock' : 'SRHHYPOLTD'},
{'sector' : 'NA', 'stock' : 'SRIPIPES'},
{'sector' : 'NA', 'stock' : 'SRSLTD'},
{'sector' : 'Finance', 'stock' : 'SRTRANSFIN'},
{'sector' : 'Auto Ancl', 'stock' : 'SSWL'},
{'sector' : 'NA', 'stock' : 'STAMPEDE'},
{'sector' : 'Pharmaceuticals', 'stock' : 'STAR'},
{'sector' : 'Paper', 'stock' : 'STARPAPER'},
{'sector' : 'Trading', 'stock' : 'STCINDIA'},
{'sector' : 'Finance', 'stock' : 'STEL'},
{'sector' : 'Pharmaceuticals', 'stock' : 'STERLINBIO'},
{'sector' : 'Misc', 'stock' : 'STERTOOLS'},
{'sector' : 'Textiles', 'stock' : 'STINDIA'},
{'sector' : 'Cables', 'stock' : 'STRTECH'},
{'sector' : 'Computers', 'stock' : 'SUBEX'},
{'sector' : 'Auto Ancl', 'stock' : 'SUBROS'},
{'sector' : 'Dyes', 'stock' : 'SUDARSCHEM'},
{'sector' : 'Appliances', 'stock' : 'SUJANAUNI'},
{'sector' : 'Textiles', 'stock' : 'SUMEETINDS'},
{'sector' : 'Finance', 'stock' : 'SUMMITSEC'},
{'sector' : 'NA', 'stock' : 'SUNCLAYLTD'},
{'sector' : 'NA', 'stock' : 'SUNDARAM'},
{'sector' : 'Finance', 'stock' : 'SUNDARMFIN'},
{'sector' : 'NA', 'stock' : 'SUNDRMBRAK'},
{'sector' : 'Auto Ancl', 'stock' : 'SUNDRMFAST'},
{'sector' : 'Steel', 'stock' : 'SUNFLAG'},
{'sector' : 'Power', 'stock' : 'SUNILHITEC'},
{'sector' : 'Pharmaceuticals', 'stock' : 'SUNPHARMA'},
{'sector' : 'Construction', 'stock' : 'SUNTECK'},
{'sector' : 'Entertainment', 'stock' : 'SUNTV'},
{'sector' : 'NA', 'stock' : 'SUPERHOUSE'},
{'sector' : 'Textiles', 'stock' : 'SUPERSPIN'},
{'sector' : 'Petrochem', 'stock' : 'SUPPETRO'},
{'sector' : 'Auto Ancl', 'stock' : 'SUPRAJIT'},
{'sector' : 'Plastics', 'stock' : 'SUPREMEIND'},
{'sector' : 'Construction', 'stock' : 'SUPREMEINF'},
{'sector' : 'Textiles', 'stock' : 'SUPREMETEX'},
{'sector' : 'NA', 'stock' : 'SURANASOL'},
{'sector' : 'Cables', 'stock' : 'SURANAT&P'},
{'sector' : 'Textiles', 'stock' : 'SURYALAXMI'},
{'sector' : 'Steel', 'stock' : 'SURYAROSNI'},
{'sector' : 'Textiles', 'stock' : 'SUTLEJTEX'},
{'sector' : 'Pharmaceuticals', 'stock' : 'SUVEN'},
{'sector' : 'Engineering', 'stock' : 'SUZLON'},
{'sector' : 'NA', 'stock' : 'SWANENERGY'},
{'sector' : 'Engines', 'stock' : 'SWARAJENG'},
{'sector' : 'NA', 'stock' : 'SWELECTES'},
{'sector' : 'NA', 'stock' : 'SYMPHONY'},
{'sector' : 'Pharmaceuticals', 'stock' : 'SYNCOM'},
{'sector' : 'Banks - PSU', 'stock' : 'SYNDIBANK'},
{'sector' : 'NA', 'stock' : 'SYNGENE'},
{'sector' : 'Plastics', 'stock' : 'TAINWALCHM'},
{'sector' : 'Hotels', 'stock' : 'TAJGVK'},
{'sector' : 'Computers', 'stock' : 'TAKE'},
{'sector' : 'Auto Ancl', 'stock' : 'TALBROAUTO'},
{'sector' : 'Misc', 'stock' : 'TALWALKARS'},
{'sector' : 'NA', 'stock' : 'TANLA'},
{'sector' : 'NA', 'stock' : 'TARAJEWELS'},
{'sector' : 'NA', 'stock' : 'TASTYBITE'},
{'sector' : 'Chemicals', 'stock' : 'TATACHEM'},
{'sector' : 'Tea-Coffee', 'stock' : 'TATACOFFEE'},
{'sector' : 'Telecom', 'stock' : 'TATACOMM'},
{'sector' : 'Computers', 'stock' : 'TATAELXSI'},
{'sector' : 'Tea-Coffee', 'stock' : 'TATAGLOBAL'},
{'sector' : 'Finance', 'stock' : 'TATAINVEST'},
{'sector' : 'Steel', 'stock' : 'TATAMETALI'},
{'sector' : 'Auto', 'stock' : 'TATAMOTORS'},
{'sector' : 'Auto', 'stock' : 'TATAMTRDVR'},
{'sector' : 'Power', 'stock' : 'TATAPOWER'},
{'sector' : 'Steel', 'stock' : 'TATASPONGE'},
{'sector' : 'Steel', 'stock' : 'TATASTEEL'},
{'sector' : 'NA', 'stock' : 'TBZ'},
{'sector' : 'Transport', 'stock' : 'TCI'},
{'sector' : 'NA', 'stock' : 'TCIDEVELOP'},
{'sector' : 'NA', 'stock' : 'TCIEXP'},
{'sector' : 'Finance', 'stock' : 'TCIFINANCE'},
{'sector' : 'Computers', 'stock' : 'TCS'},
{'sector' : 'NA', 'stock' : 'TDPOWERSYS'},
{'sector' : 'NA', 'stock' : 'TEAMLEASE'},
{'sector' : 'Computers', 'stock' : 'TECHM'},
{'sector' : 'Electric', 'stock' : 'TECHNO'},
{'sector' : 'Computers', 'stock' : 'TECHNOFAB'},
{'sector' : 'NA', 'stock' : 'TERASOFT'},
{'sector' : 'NA', 'stock' : 'TEXINFRA'},
{'sector' : 'NA', 'stock' : 'TEXRAIL'},
{'sector' : 'Finance', 'stock' : 'TFCILTD'},
{'sector' : 'NA', 'stock' : 'TGBHOTELS'},
{'sector' : 'Jewellery', 'stock' : 'THANGAMAYL'},
{'sector' : 'Pharmaceuticals', 'stock' : 'THEMISMED'},
{'sector' : 'Misc', 'stock' : 'THERMAX'},
{'sector' : 'Sugar', 'stock' : 'THIRUSUGAR'},
{'sector' : 'Travel', 'stock' : 'THOMASCOOK'},
{'sector' : 'NA', 'stock' : 'THYROCARE'},
{'sector' : 'Beverages', 'stock' : 'TI'},
{'sector' : 'Auto Ancl', 'stock' : 'TIDEWATER'},
{'sector' : 'Diversified', 'stock' : 'TIIL'},
{'sector' : 'Engineering', 'stock' : 'TIL'},
{'sector' : 'Packaging', 'stock' : 'TIMETECHNO'},
{'sector' : 'Auto Ancl', 'stock' : 'TIMKEN'},
{'sector' : 'Metals', 'stock' : 'TINPLATE'},
{'sector' : 'Entertainment', 'stock' : 'TIPSINDLTD'},
{'sector' : 'Chemicals', 'stock' : 'TIRUMALCHM'},
{'sector' : 'Misc', 'stock' : 'TITAN'},
{'sector' : 'NA', 'stock' : 'TMRVL'},
{'sector' : 'Consumer Goods', 'stock' : 'TNPETRO'},
{'sector' : 'Paper', 'stock' : 'TNPL'},
{'sector' : 'Appliances', 'stock' : 'TOKYOPLAST'},
{'sector' : 'Pharmaceuticals', 'stock' : 'TORNTPHARM'},
{'sector' : 'Power', 'stock' : 'TORNTPOWER'},
{'sector' : 'NA', 'stock' : 'TPLPLASTEH'},
{'sector' : 'NA', 'stock' : 'TREEHOUSE'},
{'sector' : 'Retail', 'stock' : 'TRENT'},
{'sector' : 'Engineering', 'stock' : 'TRF'},
{'sector' : 'Textiles', 'stock' : 'TRIDENT'},
{'sector' : 'Computers', 'stock' : 'TRIGYN'},
{'sector' : 'NA', 'stock' : 'TRIL'},
{'sector' : 'NA', 'stock' : 'TRITURBINE'},
{'sector' : 'Sugar', 'stock' : 'TRIVENI'},
{'sector' : 'NA', 'stock' : 'TTKHLTCARE'},
{'sector' : 'Appliances', 'stock' : 'TTKPRESTIG'},
{'sector' : 'Textiles', 'stock' : 'TTL'},
{'sector' : 'Telecom', 'stock' : 'TTML'},
{'sector' : 'Cycles', 'stock' : 'TUBEINVEST'},
{'sector' : 'Petrochem', 'stock' : 'TULSI'},
{'sector' : 'Entertainment', 'stock' : 'TV18BRDCST'},
{'sector' : 'Computers', 'stock' : 'TVSELECT'},
{'sector' : 'Auto', 'stock' : 'TVSMOTOR'},
{'sector' : 'Auto Ancl', 'stock' : 'TVSSRICHAK'},
{'sector' : 'Entertainment', 'stock' : 'TVTODAY'},
{'sector' : 'NA', 'stock' : 'TVVISION'},
{'sector' : 'Engineering', 'stock' : 'TWL'},
{'sector' : 'NA', 'stock' : 'UBL'},
{'sector' : 'Auto Ancl', 'stock' : 'UCALFUEL'},
{'sector' : 'Banks - PSU', 'stock' : 'UCOBANK'},
{'sector' : 'Packaging', 'stock' : 'UFLEX'},
{'sector' : 'NA', 'stock' : 'UFO'},
{'sector' : 'Sugar', 'stock' : 'UGARSUGAR'},
{'sector' : 'NA', 'stock' : 'UJAAS'},
{'sector' : 'NA', 'stock' : 'UJJIVAN'},
{'sector' : 'Cement', 'stock' : 'ULTRACEMCO'},
{'sector' : 'NA', 'stock' : 'UMANGDAIRY'},
{'sector' : 'Pharmaceuticals', 'stock' : 'UNICHEMLAB'},
{'sector' : 'Trading', 'stock' : 'UNIENTER'},
{'sector' : 'Banks - PSU', 'stock' : 'UNIONBANK'},
{'sector' : 'Construction', 'stock' : 'UNITECH'},
{'sector' : 'Banks - PSU', 'stock' : 'UNITEDBNK'},
{'sector' : 'NA', 'stock' : 'UNITEDTEA'},
{'sector' : 'Infrastructure', 'stock' : 'UNITY'},
{'sector' : 'Cables', 'stock' : 'UNIVCABLES'},
{'sector' : 'NA', 'stock' : 'UPL'},
{'sector' : 'Steel', 'stock' : 'USHAMART'},
{'sector' : 'Food Processing', 'stock' : 'USHERAGRO'},
{'sector' : 'Steel', 'stock' : 'UTTAMSTL'},
{'sector' : 'Sugar', 'stock' : 'UTTAMSUGAR'},
{'sector' : 'NA', 'stock' : 'V2RETAIL'},
{'sector' : 'NA', 'stock' : 'VADILALIND'},
{'sector' : 'NA', 'stock' : 'VAKRANGEE'},
{'sector' : 'Consumer Goods', 'stock' : 'VALUEIND'},
{'sector' : 'Textiles', 'stock' : 'VARDHACRLC'},
{'sector' : 'Textiles', 'stock' : 'VARDMNPOLY'},
{'sector' : 'Construction', 'stock' : 'VASCONEQ'},
{'sector' : 'NA', 'stock' : 'VASWANI'},
{'sector' : 'NA', 'stock' : 'VBL'},
{'sector' : 'Metals', 'stock' : 'VEDL'},
{'sector' : 'Misc', 'stock' : 'VENKEYS'},
{'sector' : 'Pharmaceuticals', 'stock' : 'VENUSREM'},
{'sector' : 'Misc', 'stock' : 'VESUVIUS'},
{'sector' : 'NA', 'stock' : 'VETO'},
{'sector' : 'NA', 'stock' : 'VGUARD'},
{'sector' : 'Finance', 'stock' : 'VHL'},
{'sector' : 'Hotels', 'stock' : 'VICEROY'},
{'sector' : 'Consumer Goods', 'stock' : 'VIDEOIND'},
{'sector' : 'NA', 'stock' : 'VIDHIING'},
{'sector' : 'Banks - PSU', 'stock' : 'VIJAYABANK'},
{'sector' : 'Construction', 'stock' : 'VIJSHAN'},
{'sector' : 'NA', 'stock' : 'VIKASECO'},
{'sector' : 'Misc', 'stock' : 'VIMTALABS'},
{'sector' : 'Chemicals', 'stock' : 'VINATIORGA'},
{'sector' : 'Cables', 'stock' : 'VINDHYATEL'},
{'sector' : 'Chemicals', 'stock' : 'VINYLINDIA'},
{'sector' : 'NA', 'stock' : 'VIPCLOTHNG'},
{'sector' : 'Plastics', 'stock' : 'VIPIND'},
{'sector' : 'NA', 'stock' : 'VIPULLTD'},
{'sector' : 'Cement', 'stock' : 'VISAKAIND'},
{'sector' : 'Steel', 'stock' : 'VISASTEEL'},
{'sector' : 'NA', 'stock' : 'VISHNU'},
{'sector' : 'NA', 'stock' : 'VIVIDHA'},
{'sector' : 'NA', 'stock' : 'VIVIMEDLAB'},
{'sector' : 'Finance', 'stock' : 'VLSFINANCE'},
{'sector' : 'NA', 'stock' : 'VMART'},
{'sector' : 'Power', 'stock' : 'VOLTAMP'},
{'sector' : 'Diversified', 'stock' : 'VOLTAS'},
{'sector' : 'NA', 'stock' : 'VRLLOG'},
{'sector' : 'NA', 'stock' : 'VSSL'},
{'sector' : 'Cigarettes', 'stock' : 'VSTIND'},
{'sector' : 'NA', 'stock' : 'VSTTILLERS'},
{'sector' : 'Textiles', 'stock' : 'VTL'},
{'sector' : 'Engineering', 'stock' : 'WABAG'},
{'sector' : 'NA', 'stock' : 'WABCOINDIA'},
{'sector' : 'Engineering', 'stock' : 'WALCHANNAG'},
{'sector' : 'NA', 'stock' : 'WEIZFOREX'},
{'sector' : 'Textiles', 'stock' : 'WEIZMANIND'},
{'sector' : 'Steel', 'stock' : 'WELCORP'},
{'sector' : 'NA', 'stock' : 'WELENT'},
{'sector' : 'NA', 'stock' : 'WELINV'},
{'sector' : 'Textiles', 'stock' : 'WELSPUNIND'},
{'sector' : 'Grinding Wheels', 'stock' : 'WENDT'},
{'sector' : 'NA', 'stock' : 'WHEELS'},
{'sector' : 'Consumer Goods', 'stock' : 'WHIRLPOOL'},
{'sector' : 'NA', 'stock' : 'WINDMACHIN'},
{'sector' : 'NA', 'stock' : 'WINSOME'},
{'sector' : 'Computers', 'stock' : 'WIPRO'},
{'sector' : 'Pharmaceuticals', 'stock' : 'WOCKPHARMA'},
{'sector' : 'NA', 'stock' : 'WONDERLA'},
{'sector' : 'Electric', 'stock' : 'WSI'},
{'sector' : 'Paper', 'stock' : 'WSTCSTPAPR'},
{'sector' : 'NA', 'stock' : 'XCHANGING'},
{'sector' : 'Packaging', 'stock' : 'XPROINDIA'},
{'sector' : 'Banks - Private', 'stock' : 'YESBANK'},
{'sector' : 'Construction', 'stock' : 'ZANDUREALT'},
{'sector' : 'Entertainment', 'stock' : 'ZEEL'},
{'sector' : 'NA', 'stock' : 'ZEELEARN'},
{'sector' : 'NA', 'stock' : 'ZEEMEDIA'},
{'sector' : 'NA', 'stock' : 'ZENSARTECH'},
{'sector' : 'NA', 'stock' : 'ZENTEC'},
{'sector' : 'Electronics', 'stock' : 'ZICOM'},
{'sector' : 'Textiles', 'stock' : 'ZODIACLOTH'},
{'sector' : 'Jewellery', 'stock' : 'ZODJRDMKJ'},
{'sector' : 'NA', 'stock' : 'ZUARI'},
{'sector' : 'NA', 'stock' : 'ZUARIGLOB'},
{'sector' : 'Misc', 'stock' : 'ZYDUSWELL'},
{'sector' : 'Computers', 'stock' : 'ZYLOG'}
]


import nsepython
from portfoliotools.screener.stock_detail import StockDetail
import pandas as pd
import numpy as np
from datetime import datetime
from statsmodels.tsa.arima_model import ARIMA
from sklearn.metrics import mean_squared_error
import scipy.stats as st

class OptionHelper:
    
    def fnoList(self):
        return nsepython.fnolist()
    
    def smape_kun(self, y_true, y_pred):
        return np.mean((np.abs(y_pred - y_true) * 200/ (np.abs(y_pred) +       np.abs(y_true))))
    
    def stockPrice(self, ticker, focus_period = 1000, lookback_period = 30, return_period = 1):
        stockObj = StockDetail(ticker, period = focus_period)
        prices = stockObj.calculate_return(return_period) # return_period Returns
        prices['Risk'] = prices['Return'].rolling( window = lookback_period).std()*np.sqrt(360/return_period) # return_period Risk
        prices['Return'] = prices['Return']*(360/return_period)
        return prices
    
    def getFutures(self, ticker):
        try:
            data = nsepython.nse_fno(ticker)
            data = [info.get('metadata', {}) for info in data['stocks'] if info.get('metadata',{}).get('instrumentType','') == 'Stock Futures']
            data = pd.DataFrame(data)
            data['expiryDate'] = data['expiryDate'].apply(lambda x: datetime.strptime(x, '%d-%b-%Y').strftime('%Y-%m-%d'))
            data['futurePrice'] = data['closePrice']
        except:
            data = pd.DataFrame(columns=['expiryDate', 'futurePrice'])
        return data

    def predict(self, df):
        result = {
                'MSE'         : np.nan,
                'SMAPE KUN'    : np.nan,
                'Pred Value'   : np.nan,
                'SD' : np.nan,
                'Pred Low 50%'  : np.nan,
                'Pred High 50%' :np.nan,
                'Model':None
            }
        train_data, test_data = df[0:int(len(df)*0.8)], df[int(len(df)*0.8):]

        train, test = train_data['data'].values, test_data['data'].values
        history = [x for x in train]
        predictions = list()
        p = 5
        d = 0
        q = 1
        for t in range(len(test)):
            model = ARIMA(history, order=(p,q,d))
            model_fit = model.fit(disp=0)
            output = model_fit.forecast()
            yhat = output[0]
            predictions.append(yhat)
            obs = test[t]
            history.append(obs)
        error = mean_squared_error(test, predictions)
        result['MSE'] = np.round(error, 3)
        error2 = self.smape_kun(test, predictions)
        result['SMAPE KUN'] = np.round(error2, 3)

        model = ARIMA(history, order=(p,q,d))
        model_fit = model.fit(disp=0)
        result['Model'] = model_fit
        output = model_fit.forecast(alpha =0.5)
        result['Pred Value']  = np.round(output[0][0],2)
        result['SD']  = np.round(output[1][0],2)
        result['Pred Low 50%'] = np.round(output[2][0][0],2)
        result['Pred High 50%']= np.round(output[2][0][1],2)
        return result
    
    def optionChain(self, ticker, predict = True):
        option_chain = nsepython.option_chain(ticker)
        result = []
        for data in option_chain['records']['data']:
            pe = data.get('PE', None)
            ce = data.get('CE', None)
            if pe is not None:
                result.append({
                    'strikePrice': data.get('strikePrice',0),
                    'expiryDate': data.get('expiryDate', ''),
                    'optionType': 'Put',
                    'closePrice': pe.get('lastPrice', 0),
                    'totalBuyQuantity': pe.get('totalBuyQuantity', 0),
                    'totalSellQuantity' : pe.get('totalSellQuantity', 0),
                    'openInterest' : pe.get('openInterest', 0),
                    'pchangeinOpenInterest' : pe.get('pchangeinOpenInterest', 0),
                    'identifier' : pe.get('identifier', ''),
                    'numberOfContractsTraded' : pe.get('totalTradedVolume', 0),
                    'impliedVolatility' : pe.get('impliedVolatility', 0),
                    'pChange' : pe.get('pChange', 0),
                    'underlyingValue' : pe.get('underlyingValue', 0),
                })
            if ce is not None:
                result.append({
                    'strikePrice': data.get('strikePrice',0),
                    'expiryDate': data.get('expiryDate', ''),
                    'optionType': 'Call',
                    'closePrice': ce.get('lastPrice', 0),
                    'totalBuyQuantity': ce.get('totalBuyQuantity', 0),
                    'totalSellQuantity' : ce.get('totalSellQuantity', 0),
                    'openInterest' : ce.get('openInterest', 0),
                    'pchangeinOpenInterest' : ce.get('pchangeinOpenInterest', 0),
                    'identifier' : ce.get('identifier', ''),
                    'numberOfContractsTraded' : ce.get('totalTradedVolume', 0),
                    'impliedVolatility' : ce.get('impliedVolatility', 0),
                    'pChange' : ce.get('pChange', 0),
                    'underlyingValue' : ce.get('underlyingValue', 0),
                })
        option_chain = pd.DataFrame(result)
        option_chain['expiryDate'] = option_chain['expiryDate'].apply(lambda x: datetime.strptime(x, '%d-%b-%Y').strftime('%Y-%m-%d'))
        expiryDates = option_chain['expiryDate'].unique()
        
        # Predict Price Range
        prices = self.stockPrice(ticker, focus_period = 365)
        data = prices[['Adj Close']]
        data.rename(columns={'Adj Close' : 'Close'}, inplace=True)
        # Expiry Dates
        daysToExpiry = [(datetime.strptime(d, '%Y-%m-%d') - datetime.now()).days for d in expiryDates]
        daysToExpiry = [z - round(z/7)*2 for z in daysToExpiry]
        forecast = {}
        i=0
        for days in daysToExpiry:
            data['Low_'+ str(days)] = data['Close'].rolling( window = days).min()
            data['Low_'+ str(days)] = data['Low_'+ str(days)].shift(-1*(days-1))
            data['High_'+ str(days)] = data['Close'].rolling( window = days).max()
            data['High_'+ str(days)] = data['High_'+ str(days)].shift(-1*(days-1))
            #data['Return_'+ str(days)] = (data['Close']/data['Close'].shift(days)-1)*100
            data['High_'+ str(days)] = ((data['High_'+ str(days)]/data['Close'])-1)*100
            data['Low_'+ str(days)] = ((data['Low_'+ str(days)]/data['Close'])-1)*100
            df_High = pd.DataFrame(data = data['High_'+ str(days)].values, columns = ['data'])
            df_Low = pd.DataFrame(data = data['Low_'+ str(days)].values, columns = ['data'])
            df_High.dropna(inplace=True)
            df_Low.dropna(inplace=True)
            temp = {}
            if predict:
                temp['High'] = self.predict(df_High)
                temp['Low'] = self.predict(df_Low)
            temp['DaysToExpiry'] = days
            forecast[expiryDates[i]] = temp
            i+=1
        # Append price ranges
        if predict:
            option_chain['predHighMean'] = option_chain['expiryDate'].apply(lambda x: forecast[x]['High']['Pred Value'])
            option_chain['predLowMean'] = option_chain['expiryDate'].apply(lambda x: forecast[x]['Low']['Pred Value'])
            option_chain['predHighSD'] = option_chain['expiryDate'].apply(lambda x: forecast[x]['High']['SD'])
            option_chain['predLowSD'] = option_chain['expiryDate'].apply(lambda x: forecast[x]['Low']['SD'])
        option_chain['daysToExpiry'] = option_chain['expiryDate'].apply(lambda x: forecast[x]['DaysToExpiry'])
        option_chain['ticker'] = ticker
        option_chain['Historical_IV'] = prices.tail(1)['Risk'].values[0]
        futures = self.getFutures(ticker)
        option_chain = option_chain.merge(futures[['expiryDate', 'futurePrice']], how = 'left', right_on='expiryDate', left_on='expiryDate')
        option_chain['futurePrice'].fillna(0, inplace=True)
        return option_chain
    
    def formatedOptionChain(self, ticker, predict = True):
        
        option_chain = self.optionChain(ticker, predict)
        if predict:
            df = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).agg({'numberOfContractsTraded' : sum, 
                                                                               'underlyingValue': max,
                                                                              'predHighMean': max,
                                                                              'predLowMean':max,
                                                                              'predHighSD':max,
                                                                              'predLowSD':max,
                                                                              'daysToExpiry':max,
                                                                              'Historical_IV': max,
                                                                              'futurePrice': max})
        else:
            df = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).agg({'numberOfContractsTraded' : sum, 
                                                                                   'underlyingValue': max,
                                                                                   'daysToExpiry':max,
                                                                                   'Historical_IV': max,
                                                                                   'futurePrice': max})
            
        df['call_price'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.callPrice)
        df['put_price'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.putPrice)
        df['iv_pe'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.groupImpliedVolatility,'Put')
        df['iv_ce'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.groupImpliedVolatility,'Call')
        df = df.reset_index()
        df['call_cost_per'] = df['call_price'] *100/df['underlyingValue']
        df['put_cost_per'] = df['put_price'] *100/df['underlyingValue']
        #df = df[df['iv_ce'] > 0]
        #df = df[df['iv_pe'] > 0]
        
        return df

    def straddleCost(self, data):
        try:
            callPrice = list(data[data['optionType'] == 'Call']['closePrice'].values)[0]
            putPrice = list(data[data['optionType'] == 'Put']['closePrice'].values)[0]
            return callPrice + putPrice
        except:
            return 0

    def callPrice(self, data):
        try:
            callPrice = list(data[data['optionType'] == 'Call']['closePrice'].values)[0]
            return callPrice
        except:
            return 0

    def putPrice(self, data):
        try:
            putPrice = list(data[data['optionType'] == 'Put']['closePrice'].values)[0]
            return putPrice
        except:
            return 0

    def straddleBreakEven(self, data, direction = 'up', displayPercent = False):
        try:
            cost = self.straddleCost(data)
            strike = list(data['strikePrice'].values)[0]
            spot = list(data['underlyingValue'].values)[0]
            if direction == 'up':
                price = strike + cost
            else:
                price = strike - cost
            if displayPercent:
                if spot != 0:
                    return ((price - spot)*100 / spot)
                else:
                    np.nan
            else:
                return price
        except:
            return 0

    def groupImpliedVolatility(self, data, optionType = 'Call'):
        try:
            return list(data[data['optionType'] == optionType]['impliedVolatility'].values)[0]
        except:
            return 0

    def calStdProbITM(self, breakEven, current, iv, expiry, optionType = 'CALL'):
        delta = round(100-100*st.norm.cdf(np.log(breakEven/current)/(iv*.01 * np.sqrt(expiry/250))),2)
        if optionType == 'CALL':
            return delta
        else:
            return 100-delta
        
    def getStraddleStrategy(self, ticker):
        option_chain = self.optionChain(ticker, True)
        straddleDetails = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).agg({'numberOfContractsTraded' : sum, 
                                                                           'underlyingValue': max,
                                                                          'predHighMean': max,
                                                                          'predLowMean':max,
                                                                          'predHighSD':max,
                                                                          'predLowSD':max,
                                                                          'daysToExpiry':max,
                                                                            'Historical_IV': max,
                                                                            'futurePrice': max})
        straddleDetails['call_price'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.callPrice)
        straddleDetails['put_price'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.putPrice)
        straddleDetails['cost'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.straddleCost)
        straddleDetails['breakeven_up'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.straddleBreakEven,'up')
        straddleDetails['breakeven_down'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.straddleBreakEven,'down')
        straddleDetails['breakeven_up_per'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.straddleBreakEven,'up', True)
        straddleDetails['breakeven_down_per'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.straddleBreakEven,'down', True)
        straddleDetails['iv_pe'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.groupImpliedVolatility,'Put')
        straddleDetails['iv_ce'] = option_chain.groupby(['ticker', 'expiryDate', 'strikePrice']).apply(self.groupImpliedVolatility,'Call')
        straddleDetails = straddleDetails[straddleDetails['numberOfContractsTraded'] > 0]
        straddleDetails = straddleDetails[straddleDetails['iv_ce'] > 0]
        straddleDetails = straddleDetails[straddleDetails['iv_pe'] > 0]

        straddleDetails = straddleDetails.reset_index()
        straddleDetails['call_per'] = straddleDetails['call_price'] *100/straddleDetails['underlyingValue']
        straddleDetails['put_per'] = straddleDetails['put_price'] *100/straddleDetails['underlyingValue']
        straddleDetails['cost_per'] = straddleDetails['cost'] *100/straddleDetails['underlyingValue']
        straddleDetails['probITMCall'] = straddleDetails[['strikePrice', 'call_price', 'underlyingValue', 'iv_ce', 'daysToExpiry']].apply(lambda x: self.calStdProbITM(x['strikePrice'] + x['call_price'],x['underlyingValue'],x['iv_ce'], x['daysToExpiry'], 'CALL'), axis=1)
        straddleDetails['probUpStd'] = straddleDetails[['breakeven_up', 'underlyingValue', 'iv_ce', 'daysToExpiry']].apply(lambda x: self.calStdProbITM(x['breakeven_up'],x['underlyingValue'],x['iv_ce'], x['daysToExpiry'], 'CALL'), axis=1)
        straddleDetails['probUpPredict'] = straddleDetails[['predHighMean', 'predHighSD','breakeven_up_per','cost_per','iv_ce', 'daysToExpiry']].apply(lambda x: round(100-st.norm.cdf((x['breakeven_up_per'] + x['cost_per']*.1 - x['predHighMean'])/max(x['predHighSD'],x['iv_ce'] * np.sqrt(x['daysToExpiry']/250)))*100,2), axis=1)
        straddleDetails['probITMPut'] = straddleDetails[['strikePrice', 'put_price', 'underlyingValue', 'iv_pe', 'daysToExpiry']].apply(lambda x: self.calStdProbITM(x['strikePrice'] - x['put_price'],x['underlyingValue'],x['iv_pe'], x['daysToExpiry'], 'PUT'), axis=1)
        straddleDetails['probDownStd'] = straddleDetails[['breakeven_down', 'underlyingValue', 'iv_pe', 'daysToExpiry']].apply(lambda x: self.calStdProbITM(x['breakeven_down'],x['underlyingValue'],x['iv_pe'], x['daysToExpiry'], 'PUT'), axis=1)
        straddleDetails['probDownPredict'] = straddleDetails[['predLowMean', 'predLowSD','breakeven_down_per','cost_per','iv_pe','daysToExpiry']].apply(lambda x: round(st.norm.cdf((x['breakeven_down_per']-x['cost_per']*.1 - x['predLowMean'])/max(x['predLowSD'],x['iv_pe'] * np.sqrt(x['daysToExpiry']/250)))*100,2), axis=1)
        straddleDetails['probITMLongStraddle'] = (straddleDetails['probUpPredict'] + straddleDetails['probDownPredict'])
        straddleDetails['probITMLongStraddleStd'] = straddleDetails['probUpStd'] + straddleDetails['probDownStd']
        #straddleDetails = straddleDetails[straddleDetails.columns.drop(['probUpStd', 'probUpPredict', 'probDownStd', 'probDownPredict', 'predHighMean', 'predHighSD','predLowMean', 'predLowSD'])]
        return straddleDetails